﻿using System;
using System.Diagnostics;
using System.Text;
using System.Drawing;
using com.epson.bank.driver;

namespace TMS_Sample
{
	class CEndorse
	{
		private const uint TRANS_NO_SPECIFIED = 0x40000000;
		private CProperty_1 m_objProperty = null;

		public CEndorse()
		{
		}

		public ErrorCode Init(CProperty_1 objProperty)
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			m_objProperty = objProperty;

			return errResult;
		}

		public ErrorCode LoadEndorseFile()
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			// Loading printing region setting file for template printing
			int nLoadNum = 0;
			StringBuilder sbPath = new StringBuilder();
			string szPath = null;

			sbPath.Append(System.IO.Directory.GetCurrentDirectory());
			sbPath.Append("\\FormatSettingStep4.ini");
			szPath = sbPath.ToString();

			// Set print information for physical endorsement
			errResult = m_objProperty.GetMfDevice().SetPrintStation(PrintingStation.MF_ST_PHYSICAL_ENDORSEMENT);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			errResult = m_objProperty.GetMfDevice().LoadTemplatePrintArea(szPath, out nLoadNum);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			// Set print information for electronic endorsement
			errResult = m_objProperty.GetMfDevice().SetPrintStation(PrintingStation.MF_ST_E_ENDORSEMENT);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			errResult = m_objProperty.GetMfDevice().LoadTemplatePrintArea(szPath, out nLoadNum);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			return errResult;
		}

		public ErrorCode SetEndorseStation()
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			// Select print station
			errResult = m_objProperty.GetMfDevice().SetPrintStation(m_objProperty.GetEndorseType());
			Debug.Assert(errResult == ErrorCode.SUCCESS);

			if (m_objProperty.GetPayeeEndorse())
			{
				errResult = m_objProperty.GetMfDevice().SetConfigure(
						ConfigID.MF_CONFIG_ID_ENDORSE_PRINT_POSITION,
						ConfigType.MF_CONFIG_TYPE_ENDORSE_PRINT_POSITION_PAYEE_ENDORSE);
			}
			else
			{
				// Driver's default.
				errResult = m_objProperty.GetMfDevice().SetConfigure(
						ConfigID.MF_CONFIG_ID_ENDORSE_PRINT_POSITION,
						ConfigType.MF_CONFIG_TYPE_ENDORSE_PRINT_POSITION_NORMAL);
			}

			return errResult;
		}

		public ErrorCode PhysicalEndorseFunction( uint unTransactionNumber )
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			// Start buffering of print data for format printing
			errResult = m_objProperty.GetMfDevice().TemplatePrint(TemplatePrintMode.TEMPLATEPRINT_BUFFERING);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			// set strings for printing
			{
				DateTime stDateTime;
				MFTrueType mfDecorate = new MFTrueType();
				System.Drawing.Font objFont = null;
				string szPhysicalEndorse = null;
				StringBuilder sbPhysicalEndorse = new StringBuilder();
				string[] stMonth = new string[] { "", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };

				/*PhysicalEndorseText1*/
				if (m_objProperty.GetPayeeEndorse())
				{
					errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "PhysicalEndorseText1_CW", null, unTransactionNumber);
				}
				else
				{
					errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "PhysicalEndorseText1", null, unTransactionNumber);
				}
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				objFont = new System.Drawing.Font("Arial", 9);
				mfDecorate.Font = objFont;

				stDateTime = DateTime.Now;
				sbPhysicalEndorse.Append("  " + stMonth[stDateTime.Month] + " "
											  + stDateTime.Day.ToString("00") + " " + stDateTime.Year.ToString("0000") + "\r\n");
				sbPhysicalEndorse.Append("  " + stDateTime.Hour.ToString("00") + ":" + stDateTime.Minute.ToString("00") + ":"
											  + stDateTime.Second.ToString("00") + ":" + stDateTime.Millisecond.ToString() + "\r\n\r\n");
				sbPhysicalEndorse.Append("  &>1234567890&<");
				szPhysicalEndorse = sbPhysicalEndorse.ToString();

				errResult = m_objProperty.GetMfDevice().SCNPrintText(unTransactionNumber, szPhysicalEndorse, mfDecorate);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				/*PhysicalEndorseText2*/
				if (m_objProperty.GetPayeeEndorse())
				{
					errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "PhysicalEndorseText2_CW", null, unTransactionNumber);
				}
				else
				{
					errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "PhysicalEndorseText2", null, unTransactionNumber);
				}
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				szPhysicalEndorse = "  &>1234567890&<";

				errResult = m_objProperty.GetMfDevice().SCNPrintText(unTransactionNumber, szPhysicalEndorse, mfDecorate);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}
			}

			// Print buffered data
			errResult = m_objProperty.GetMfDevice().TemplatePrint(TemplatePrintMode.TEMPLATEPRINT_EXEC);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			return errResult;
		}

		public ErrorCode ElectronicEndorseFunction(uint unTransactionNumber)
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			// Start buffering of print data for format printing
			errResult = m_objProperty.GetMfDevice().TemplatePrint(TemplatePrintMode.TEMPLATEPRINT_BUFFERING);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			// set strings for printing
			{
				DateTime stDateTime;
				MFTrueType mfDecorate = new MFTrueType();
				System.Drawing.Font objFont = null;
				string szElectronicEndorse = null;
				StringBuilder sbElectronicEndorse = new StringBuilder();
				string[] stMonth = new string[] { "", "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };

				/*ElectronicEndorseText1*/
				errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "ElectronicEndorseText1", null, TRANS_NO_SPECIFIED);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				objFont = new System.Drawing.Font("Arial", 9);
				mfDecorate.Font = objFont;

				stDateTime = DateTime.Now;
				sbElectronicEndorse.Append("  " + stMonth[stDateTime.Month] + " "
											  + stDateTime.Day.ToString("00") + " " + stDateTime.Year.ToString("0000") + "\r\n");
				sbElectronicEndorse.Append("  " + stDateTime.Hour.ToString("00") + ":" + stDateTime.Minute.ToString("00") + ":"
											  + stDateTime.Second.ToString("00") + ":" + stDateTime.Millisecond.ToString() + "\r\n\r\n");
				sbElectronicEndorse.Append("  &>1234567890&<");
				szElectronicEndorse = sbElectronicEndorse.ToString();

				errResult = m_objProperty.GetMfDevice().PrintText(szElectronicEndorse, mfDecorate);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				/*ElectronicEndorseText2*/
				errResult = m_objProperty.GetMfDevice().SetTemplatePrintArea(AreaSelectMode.SELECTPRINTAREA_AREANAME, "ElectronicEndorseText2", null, TRANS_NO_SPECIFIED);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}

				szElectronicEndorse = "  &>1234567890&<";

				errResult = m_objProperty.GetMfDevice().PrintText(szElectronicEndorse, mfDecorate);
				Debug.Assert(errResult == ErrorCode.SUCCESS);
				if (errResult != ErrorCode.SUCCESS)
				{
					return errResult;
				}
			}

			// Print buffered data
			errResult = m_objProperty.GetMfDevice().TemplatePrint(TemplatePrintMode.TEMPLATEPRINT_EXEC);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			return errResult;
		}
	}
}
