﻿using System;
using System.Diagnostics;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using com.epson.bank.driver;

namespace TMS_Sample
{
	public partial class IqaResultForm : Form
	{
		// Deligates types
		public delegate void DisplayIqaResultType( CIqaResult objIqaResult );

		// Deligates to invoke
		public DisplayIqaResultType DisplayIqaResult = null;

		public IqaResultForm()
		{
			InitializeComponent();
		}

		private void IqaResultForm_Load(object sender, EventArgs e)
		{
			LoadResourceString();

			// Setting up deligates to invoke
			DisplayIqaResult = new DisplayIqaResultType(DisplayIqaResultImpl);
		}

		private void IqaResultForm_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (e.CloseReason == CloseReason.UserClosing)
			{
				Hide();
				e.Cancel = true;
			}
		}

		public void LoadResourceString()
		{
			btnClose.Text = ConstComStr.STR_IQARESULTDLG_BUTTON_CLOSE;

			stIQUnderSize.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_UNDERSIZE;
			stIQOverSize.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_OVERSIZE;
			stIQMinCompressed.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_MINCOMPRESSED;
			stIQMaxCompressed.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_MAXCOMPRESSED;
			stIQFrontRearMismatch.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_FRONTREARMISMATCH;
			stIQTooLight.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_TOOLIGHT;
			stIQTooDark.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_TOODARK;
			stIQHorizontalStreaks.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_HORIZONTALSTREAKS;
			stIQSpotNoise.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_SPOTNOISE;
			stIQOutOfFocus.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_OUTOFFOCUS;
			stIQDocCorners.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_DOCCORNERS;
			stIQDocEdges.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_DOCEDGES;
			stIQFramingError.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_FRAMINGERROR;
			stIQSkew.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_SKEW;
			stIQCarbonStrip.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_CARBONSTRIP;
			stIQPiggyback.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_PIGGYBACK;
		}

		public void DisplayIqaResultImpl( CIqaResult objIqaResult )
		{
			if (this.InvokeRequired)
			{
				this.BeginInvoke(DisplayIqaResult, new object[] { objIqaResult });
				return;
			}

			Debug.Assert(objIqaResult != null);
			if(objIqaResult == null)
			{
				return;
			}

			SetIqaResult(objIqaResult.GetUnderSize(), ref edtIQUnderSize);
			SetIqaResult(objIqaResult.GetOverSize(), ref edtIQOverSize);
			SetIqaResult(objIqaResult.GetMinCompressed(), ref edtIQMinCompressed);
			SetIqaResult(objIqaResult.GetMaxCompressed(), ref edtIQMaxCompressed);
			SetIqaResult(objIqaResult.GetFrontRearImageMismatch(), ref edtIQFrontRearMismatch);
			SetIqaResult(objIqaResult.GetImageTooLight(), ref edtIQTooLight);
			SetIqaResult(objIqaResult.GetImageTooDark(), ref edtIQTooDark);
			SetIqaResult(objIqaResult.GetHorizontalStreaksPresent(), ref edtIQHorizontalStreaks);
			SetIqaResult(objIqaResult.GetSpotNosise(), ref edtIQSpotNoise);
			SetIqaResult(objIqaResult.GetOutOfFocus(), ref edtIQOutOfFocus);
			SetIqaResult(objIqaResult.GetFoldedTornCorner(), ref edtIQDocCorners);
			SetIqaResult(objIqaResult.GetFoldedTornEdge(), ref edtIQDocEdges);
			SetIqaResult(objIqaResult.GetFramingError(), ref edtIQFramingError);
			SetIqaResult(objIqaResult.GetExcessiveSkew(), ref edtIQSkew);
			SetIqaResult(objIqaResult.GetCarbonStripDetection(), ref edtIQCarbonStrip);
			SetIqaResult(objIqaResult.GetPiggyback(), ref edtIQPiggyback);
		}

		private void SetIqaResult(MfIqaResultValue eIqaResult, ref TextBox edtControl)
		{
			if(edtControl == null)
			{
				Debug.Assert(false);
				return;
			}

			switch (eIqaResult)
			{
				case MfIqaResultValue.IQARESULT_NOT_TESTED:
					edtControl.Text = "Not Tested.";
					break;
				case MfIqaResultValue.IQARESULT_PASS:
					edtControl.Text = "Pass.";
					break;
				case MfIqaResultValue.IQARESULT_NOT_PASS:
					edtControl.Text = "Not Pass.";
					break;
				default:
					break;
			}
		}

		public void UpdateControls(CIqaParam cIqaParam)
		{
			if (cIqaParam.GetUnderSize() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQUnderSize.Enabled = true;
				edtIQUnderSize.Enabled = true;
			}
			else
			{
				stIQUnderSize.Enabled = false;
				edtIQUnderSize.Enabled = false;
			}

			if (cIqaParam.GetOverSize() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQOverSize.Enabled = true;
				edtIQOverSize.Enabled = true;
			}
			else
			{
				stIQOverSize.Enabled = false;
				edtIQOverSize.Enabled = false;
			}

			if (cIqaParam.GetMinCompressed() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQMinCompressed.Enabled = true;
				edtIQMinCompressed.Enabled = true;
			}
			else
			{
				stIQMinCompressed.Enabled = false;
				edtIQMinCompressed.Enabled = false;
			}

			if (cIqaParam.GetMaxCompressed() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQMaxCompressed.Enabled = true;
				edtIQMaxCompressed.Enabled = true;
			}
			else
			{
				stIQMaxCompressed.Enabled = false;
				edtIQMaxCompressed.Enabled = false;
			}

			if (cIqaParam.GetFrontRearImageMismatch() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQFrontRearMismatch.Enabled = true;
				edtIQFrontRearMismatch.Enabled = true;
			}
			else
			{
				stIQFrontRearMismatch.Enabled = false;
				edtIQFrontRearMismatch.Enabled = false;
			}

			if (cIqaParam.GetImageTooLight() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQTooLight.Enabled = true;
				edtIQTooLight.Enabled = true;
			}
			else
			{
				stIQTooLight.Enabled = false;
				edtIQTooLight.Enabled = false;
			}

			if (cIqaParam.GetImageTooDark() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQTooDark.Enabled = true;
				edtIQTooDark.Enabled = true;
			}
			else
			{
				stIQTooDark.Enabled = false;
				edtIQTooDark.Enabled = false;
			}

			if (cIqaParam.GetHorizontalStreaksPresent() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQHorizontalStreaks.Enabled = true;
				edtIQHorizontalStreaks.Enabled = true;
			}
			else
			{
				stIQHorizontalStreaks.Enabled = false;
				edtIQHorizontalStreaks.Enabled = false;
			}

			if (cIqaParam.GetSpotNoise() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQSpotNoise.Enabled = true;
				edtIQSpotNoise.Enabled = true;
			}
			else
			{
				stIQSpotNoise.Enabled = false;
				edtIQSpotNoise.Enabled = false;
			}

			if (cIqaParam.GetOutOfFocus() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQOutOfFocus.Enabled = true;
				edtIQOutOfFocus.Enabled = true;
			}
			else
			{
				stIQOutOfFocus.Enabled = false;
				edtIQOutOfFocus.Enabled = false;
			}

			if (cIqaParam.GetFoldedTornCorner() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQDocCorners.Enabled = true;
				edtIQDocCorners.Enabled = true;
			}
			else
			{
				stIQDocCorners.Enabled = false;
				edtIQDocCorners.Enabled = false;
			}

			if (cIqaParam.GetFoldedTornEdge() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQDocEdges.Enabled = true;
				edtIQDocEdges.Enabled = true;
			}
			else
			{
				stIQDocEdges.Enabled = false;
				edtIQDocEdges.Enabled = false;
			}

			if (cIqaParam.GetFramingError() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQFramingError.Enabled = true;
				edtIQFramingError.Enabled = true;
			}
			else
			{
				stIQFramingError.Enabled = false;
				edtIQFramingError.Enabled = false;
			}

			if (cIqaParam.GetExcessiveSkew() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQSkew.Enabled = true;
				edtIQSkew.Enabled = true;
			}
			else
			{
				stIQSkew.Enabled = false;
				edtIQSkew.Enabled = false;
			}

			if (cIqaParam.GetCarbonStripDetection() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQCarbonStrip.Enabled = true;
				edtIQCarbonStrip.Enabled = true;
			}
			else
			{
				stIQCarbonStrip.Enabled = false;
				edtIQCarbonStrip.Enabled = false;
			}

			if (cIqaParam.GetPiggyback() == MfIqaTest.MF_IQA_TEST_ENABLE)
			{
				stIQPiggyback.Enabled = true;
				edtIQPiggyback.Enabled = true;
			}
			else
			{
				stIQPiggyback.Enabled = false;
				edtIQPiggyback.Enabled = false;
			}
		}

		private void btnClose_Click(object sender, EventArgs e)
		{
			Hide();
		}
	}
}
