﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace TMS_Sample
{
	public partial class DeviceInfoForm : Form
	{
		public DeviceInfoForm()
		{
			InitializeComponent();
		}

		private void DeviceInfoForm_Load(object sender, EventArgs e)
		{

		}

		private void DeviceInfoForm_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (e.CloseReason == CloseReason.UserClosing)
			{
				Hide();
				e.Cancel = true;
			}
		}

		public void DisplayDeviceInfo( CDeviceInfo objDeviceInfo )
		{
			if(objDeviceInfo == null)
			{
				return;
			}

			const uint TWO_POCKET_MODEL	 = 0x0002;
			const uint SCAN_200DPM_MODEL = 0x0010;
			const uint SCAN_110DPM_MODEL = 0x0008;

			edtDIDeviceName.Text = objDeviceInfo.GetDeviceName().ToString();
			edtDIFirmwareVersion.Text = objDeviceInfo.GetFirmVersion().ToString();
			edtDIManufacture.Text = objDeviceInfo.GetManufacture().ToString();
			edtDISerialNumber.Text = objDeviceInfo.GetSerialNumber().ToString();

			if( (objDeviceInfo.GetTypeIdB()[0] & TWO_POCKET_MODEL) == TWO_POCKET_MODEL )
			{
				edtDIPocket.Text = "2 pocket";
			}
			else
			{
				edtDIPocket.Text = "1 pocket";
			}

			if( (objDeviceInfo.GetTypeIdB()[0] & SCAN_200DPM_MODEL) == SCAN_200DPM_MODEL )
			{
				edtDISpeed.Text = "200DPM";
			}
			else if ((objDeviceInfo.GetTypeIdB()[0] & SCAN_110DPM_MODEL) == SCAN_110DPM_MODEL)
			{
				edtDISpeed.Text = "110DPM";
			}
		}

		public void DisplayMaintenanceCounter( CMaintenanceCounter objMaintenanceCounter )
		{
			if (objMaintenanceCounter == null)
			{
				return;
			}

			DisplayIntOnEdit( edtMCScanedCheck,         stMCScanedCheck,         objMaintenanceCounter.GetImageScannedCheckPaper() );
			DisplayIntOnEdit( edtMCScanedCard,          stMCScanedCard,          objMaintenanceCounter.GetImageScannedCard() );
			DisplayIntOnEdit( edtMCLineFeeds,           stMCLineFeeds,           objMaintenanceCounter.GetLineFeeds() );        // S9000 only
			DisplayIntOnEdit( edtMCPumpOperation,       stMCPumpOperation,       objMaintenanceCounter.GetPumpOperation() );
			DisplayIntOnEdit( edtMCMicrRead,            stMCMicrRead,            objMaintenanceCounter.GetMicrReads() );
			DisplayIntOnEdit( edtMCHeadShotA,           stMCHeadShotA,           objMaintenanceCounter.GetHeadShotA() );
			DisplayIntOnEdit( edtMCHeadShotB,           stMCHeadShotB,           objMaintenanceCounter.GetHeadShotB() );
			DisplayIntOnEdit( edtMCHeadEnergization,    stMCHeadEnergization,    objMaintenanceCounter.GetHeadEnergization() ); // S9000 only
			DisplayIntOnEdit( edtMCAsfSendingOff,       stMCAsfSendingOff,       objMaintenanceCounter.GetAsfSendingOff() );
			DisplayIntOnEdit( edtMCHeadLineFeeds,       stMCHeadLineFeeds,       objMaintenanceCounter.GetHeadLineFeeds() );    // S9000 only
			DisplayIntOnEdit( edtMCAutoCutter,          stMCAutoCutter,          objMaintenanceCounter.GetAutoCutter() );       // S9000 only
			DisplayIntOnEdit( edtMCHopper,              stMCHopper,              objMaintenanceCounter.GetHopper() );
			DisplayIntOnEdit( edtMCPocketSelect,        stMCPocketSelect,        objMaintenanceCounter.GetPocketSelect() );
			DisplayIntOnEdit( edtMCDeviceOperationTime, stMCDeviceOperationTime, objMaintenanceCounter.GetDeviceOperationTime() );
		}

		private void DisplayIntOnEdit(TextBox edt, Label st, int n)
		{
			if ( n >= 0 )
			{
				// S9000
				st.Enabled = true;
				edt.Enabled = true;
				edt.Text = n.ToString();
			}
			else
			{
				// S2000
				st.Enabled = false;
				edt.Enabled = false;
				edt.Text = "N/A";
			}
		}

		private void btnClose_Click(object sender, EventArgs e)
		{
			Hide();
		}
	}
}
