﻿using System;
using System.Diagnostics;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

namespace TMS_Sample
{
	public partial class DeviceStatusForm : Form
	{
		// Deligates types
		public delegate void DisplayDeviceStatusType(ref CDeviceStatus objDeviceStatus);
		public delegate void DisplayInkStatusType   (ref CInkStatus    objDeviceStatus);

		// Deligates to invoke
		public DisplayDeviceStatusType DisplayDeviceStatus = null;
		public DisplayInkStatusType    DisplayInkStatus    = null;

		public DeviceStatusForm()
		{
			InitializeComponent();
		}

		private void DeviceStatusForm_Load(object sender, EventArgs e)
		{
			// Setting up deligates to invoke
			DisplayDeviceStatus = new DisplayDeviceStatusType(DisplayDeviceStatusImpl);
			DisplayInkStatus    = new DisplayInkStatusType   (DisplayInkStatusImpl);
		}

		private void DeviceStatusForm_FormClosing(object sender, FormClosingEventArgs e)
		{
			if (e.CloseReason == CloseReason.UserClosing)
			{
				Hide();
				e.Cancel = true;
			}
		}

		public void DisplayDeviceStatusImpl(ref CDeviceStatus objDeviceStatus)
		{
			if (this.InvokeRequired)
			{
				this.BeginInvoke(DisplayDeviceStatus, new object[] { objDeviceStatus });
				return;
			}

			Debug.Assert(objDeviceStatus != null);
			if (objDeviceStatus == null)
			{
				return;
			}

			if( objDeviceStatus.GetNoResponse() == true )
			{
				btnCheckDSNoResponse.Checked = true;
				btnCheckDSOffLine.Checked = false;
				btnCheckDSCoverOpen.Checked = false;
				btnCheckDSWaitPaperEject.Checked = false;
				btnCheckDSMechanicalErr.Checked = false;
				btnCheckDSUnrecoverErr.Checked = false;
				btnCheckDSPaperIntermediate.Checked = false;
				btnCheckDSReceiptNearEnd.Checked = false;     // S9000 only
				btnCheckDSEjectSensorNoPaper.Checked = false;
				btnCheckDSReceiptEnd.Checked = false;         // S9000 only
				btnCheckDSSlipPaperSize.Checked = false;
				btnCheckDSAsfPaper.Checked = false;
				btnCheckDSWaitInsert.Checked = false;
				btnCheckDSMainPocketNearFull.Checked = false;
				btnCheckDSSubPocketNearFull.Checked = false;
			}
			else if( objDeviceStatus.GetNoResponse() == false )
			{
				btnCheckDSNoResponse.Checked = false;
				btnCheckDSOffLine.Checked = objDeviceStatus.GetOffLine();
				btnCheckDSCoverOpen.Checked = objDeviceStatus.GetCoverOpen();
				btnCheckDSWaitPaperEject.Checked = objDeviceStatus.GetWaitPaperEject();
				btnCheckDSMechanicalErr.Checked = objDeviceStatus.GetMechanicalError();
				btnCheckDSUnrecoverErr.Checked = objDeviceStatus.GetUnrecoverError();
				btnCheckDSPaperIntermediate.Checked = !objDeviceStatus.GetPaperInsermadiate();
				btnCheckDSReceiptNearEnd.Checked = objDeviceStatus.GetReceiptNearEnd();        // S9000 only
				btnCheckDSEjectSensorNoPaper.Checked = !objDeviceStatus.GetEjectSensorPaper();
				btnCheckDSReceiptEnd.Checked = objDeviceStatus.GetReceiptEnd();                // S9000 only
				btnCheckDSSlipPaperSize.Checked = !objDeviceStatus.GetSlipPaperSize();
				btnCheckDSAsfPaper.Checked = !objDeviceStatus.GetAsfPaper();
				btnCheckDSWaitInsert.Checked = objDeviceStatus.GetWaitInsert();
				btnCheckDSMainPocketNearFull.Checked = objDeviceStatus.GetMainPocketNearFull();
				btnCheckDSSubPocketNearFull.Checked = objDeviceStatus.GetSubPocketNearFull();
			}
		}

		public void DisplayInkStatusImpl(ref CInkStatus objInkStatus)
		{
			if (this.InvokeRequired)
			{
				this.BeginInvoke(DisplayInkStatus, new object[] { objInkStatus });
				return;
			}

			Debug.Assert(objInkStatus != null);
			if (objInkStatus == null)
			{
				return;
			}

			btnCheckISInkNearEnd.Checked = objInkStatus.GetInkNearEnd();
			btnCheckISInkEnd.Checked = objInkStatus.GetInkEnd();
			btnCheckISInkNoCartridge.Checked = objInkStatus.GetInkNoCartridge();
			btnCheckISInkCleaning.Checked = objInkStatus.GetInkCleaning();
		}

		private void btnClose_Click(object sender, EventArgs e)
		{
			Hide();
		}
	}
}
