using System;
using System.Diagnostics;
using System.Text;
using com.epson.bank.driver;

namespace TMS_Sample
{
	class CInfo
	{
		public const int  INFO_DEVICE_NAME   =  67;
		public const int  INFO_MANUFACTURE   =  66;
		public const int  INFO_FIRM_VERSION  =  65;
		public const int  INFO_SERIAL_NUMBER =  68;
		public const int  INFO_SPEED_POCKET  = 112;

		public const int  MAX_DEVICE_INFO_SIZE = 80;

		public const int  COUNTER_HEAD_ENERGIZATION     = 21; // S9000 only
		public const int  COUNTER_HEAD_LINE_FEEDS       = 22; // S9000 only
		public const int  COUNTER_LINE_FEEDS            = 30; // S9000 only
		public const int  COUNTER_HEAD_SHOT_A           = 31;
		public const int  COUNTER_HEAD_SHOT_B           = 32;
		public const int  COUNTER_PUMP_OPERATION        = 34;
		public const int  COUNTER_AUTO_CUTTER           = 50; // S9000 only
		public const int  COUNTER_ASF_SENDING_OFF       = 67;
		public const int  COUNTER_SCANNED_CHECK         = 61;
		public const int  COUNTER_SCANNED_CARD          = 62;
		public const int  COUNTER_MICR_READS            = 60;
		public const int  COUNTER_POCKET_SELECT         = 82;
		public const int  COUNTER_HOPPER                = 80;
		public const int  COUNTER_DEVICE_OPERATION_TIME = 70;

		private CProperty_1 m_objProperty = null;

		public CInfo()
		{
		}

		public ErrorCode Init(CProperty_1 objProperty)
		{
			ErrorCode errResult = ErrorCode.SUCCESS;
			m_objProperty = objProperty;

			return errResult;
		}

		public ErrorCode GetDeviceStatusFunction(ref CDeviceStatus objDeviceStatus)
		{
			if (objDeviceStatus == null)
			{
				return ErrorCode.ERR_UNKNOWN;
			}

			ASB eStatus = m_objProperty.GetMfDevice().Status;

			// ASB_NO_RESPONSE
			if ((eStatus & ASB.ASB_NO_RESPONSE) == ASB.ASB_NO_RESPONSE)
			{
				objDeviceStatus.SetNoResponse(true);
			}
			else
			{
				objDeviceStatus.SetNoResponse(false);
			}

			// ASB_OFF_LINE
			if ((eStatus & ASB.ASB_OFF_LINE) == ASB.ASB_OFF_LINE)
			{
				objDeviceStatus.SetOffLine(true);
			}
			else
			{
				objDeviceStatus.SetOffLine(false);
			}

			// ASB_COVER_OPEN
			if ((eStatus & ASB.ASB_COVER_OPEN) == ASB.ASB_COVER_OPEN)
			{
				objDeviceStatus.SetCoverOpen(true);
			}
			else
			{
				objDeviceStatus.SetCoverOpen(false);
			}

			// ASB_WAIT_PEPRT_EJECT
			if ((eStatus & ASB.ASB_WAIT_PEPRT_EJECT) == ASB.ASB_WAIT_PEPRT_EJECT)
			{
				objDeviceStatus.SetWaitPaperEject(true);
			}
			else
			{
				objDeviceStatus.SetWaitPaperEject(false);
			}

			// ASB_MECHANICAL_ERR
			if ((eStatus & ASB.ASB_MECHANICAL_ERR) == ASB.ASB_MECHANICAL_ERR)
			{
				objDeviceStatus.SetMechanicalError(true);
			}
			else
			{
				objDeviceStatus.SetMechanicalError(false);
			}

			// ASB_UNRECOVER_ERR
			if ((eStatus & ASB.ASB_UNRECOVER_ERR) == ASB.ASB_UNRECOVER_ERR)
			{
				objDeviceStatus.SetUnrecoverError(true);
			}
			else
			{
				objDeviceStatus.SetUnrecoverError(false);
			}

			// ASB_PAPER_INTERMEDIATE
			if ((eStatus & ASB.ASB_PAPER_INTERMEDIATE) == ASB.ASB_PAPER_INTERMEDIATE)
			{
				objDeviceStatus.SetPaperInsermadiate(true);
			}
			else
			{
				objDeviceStatus.SetPaperInsermadiate(false);
			}

			// ASB_RECEIPT_NEAR_END
			if ((eStatus & ASB.ASB_RECEIPT_NEAR_END) == ASB.ASB_RECEIPT_NEAR_END)
			{
				// S9000 only
				objDeviceStatus.SetReceiptNearEnd(true);
			}
			else
			{
				objDeviceStatus.SetReceiptNearEnd(false);
			}

			// ASB_EJECT_SENSOR_NO_PAPER
			if ((eStatus & ASB.ASB_EJECT_SENSOR_NO_PAPER) == ASB.ASB_EJECT_SENSOR_NO_PAPER)
			{
				objDeviceStatus.SetEjectSensorPaper(true);
			}
			else
			{
				objDeviceStatus.SetEjectSensorPaper(false);
			}

			// ASB_RECEIPT_END
			if ((eStatus & ASB.ASB_RECEIPT_END) == ASB.ASB_RECEIPT_END)
			{
				// S9000 only
				objDeviceStatus.SetReceiptEnd(true);
			}
			else
			{
				objDeviceStatus.SetReceiptEnd(false);
			}

			// ASB_SLIP_PAPER_SIZE
			if ((eStatus & ASB.ASB_SLIP_PAPER_SIZE) == ASB.ASB_SLIP_PAPER_SIZE)
			{
				objDeviceStatus.SetSlipPaperSize(true);
			}
			else
			{
				objDeviceStatus.SetSlipPaperSize(false);
			}

			// ASB_ASF_PAPER
			if ((eStatus & ASB.ASB_ASF_PAPER) == ASB.ASB_ASF_PAPER)
			{
				objDeviceStatus.SetAsfPaper(true);
			}
			else
			{
				objDeviceStatus.SetAsfPaper(false);
			}

			// ASB_WAIT_INSERT
			if ((eStatus & ASB.ASB_WAIT_INSERT) == ASB.ASB_WAIT_INSERT)
			{
				objDeviceStatus.SetWaitInsert(true);
			}
			else
			{
				objDeviceStatus.SetWaitInsert(false);
			}

			// ASB_MAIN_POCKET_NEAR_FULL
			if ((eStatus & ASB.ASB_MAIN_POCKET_NEAR_FULL) == ASB.ASB_MAIN_POCKET_NEAR_FULL)
			{
				objDeviceStatus.SetMainPocketNearFull(true);
			}
			else
			{
				objDeviceStatus.SetMainPocketNearFull(false);
			}

			// ASB_SUB_POCKET_NEAR_FULL
			if ((eStatus & ASB.ASB_SUB_POCKET_NEAR_FULL) == ASB.ASB_SUB_POCKET_NEAR_FULL)
			{
				objDeviceStatus.SetSubPocketNearFull(true);
			}
			else
			{
				objDeviceStatus.SetSubPocketNearFull(false);
			}

			return ErrorCode.SUCCESS;
		}

		public ErrorCode GetInkStatusFunction(ref CInkStatus objInkStatus)
		{
			if (objInkStatus == null)
			{
				return ErrorCode.ERR_UNKNOWN;
			}

			InkASB eInkASB = m_objProperty.GetMfDevice().InkStatus;

			if ((eInkASB & InkASB.INK_ASB_NEAR_END) == InkASB.INK_ASB_NEAR_END)
			{
				objInkStatus.SetInkNearEnd(true);
			}
			else
			{
				objInkStatus.SetInkNearEnd(false);
			}

			if ((eInkASB & InkASB.INK_ASB_END) == InkASB.INK_ASB_END)
			{
				objInkStatus.SetInkEnd(true);
			}
			else
			{
				objInkStatus.SetInkEnd(false);
			}

			if ((eInkASB & InkASB.INK_ASB_NO_CARTRIDGE) == InkASB.INK_ASB_NO_CARTRIDGE)
			{
				objInkStatus.SetInkNoCartridge(true);
			}
			else
			{
				objInkStatus.SetInkNoCartridge(false);
			}

			if ((eInkASB & InkASB.INK_ASB_CLEANING) == InkASB.INK_ASB_CLEANING)
			{
				objInkStatus.SetInkCleaning(true);
			}
			else
			{
				objInkStatus.SetInkCleaning(false);
			}

			return ErrorCode.SUCCESS;
		}

		public ErrorCode GetDeviceInfoFunction(ref CDeviceInfo objDeviceInfo)
		{
			if(objDeviceInfo == null)
			{
				return ErrorCode.ERR_UNKNOWN;
			}

			ErrorCode errResult = ErrorCode.SUCCESS;

			// Get device name
			string sDeviceInfo;
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_DEVICE_NAME, out sDeviceInfo);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if(errResult == ErrorCode.SUCCESS)
			{
				objDeviceInfo.SetDeviceName(sDeviceInfo);
			}

			// Get manufacturer
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_MANUFACTURE, out sDeviceInfo);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if(errResult == ErrorCode.SUCCESS)
			{
				objDeviceInfo.SetManufacture(sDeviceInfo);
			}

			// Get firmware version
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_FIRM_VERSION, out sDeviceInfo);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if(errResult == ErrorCode.SUCCESS)
			{
				objDeviceInfo.SetFirmVersion(sDeviceInfo);
			}

			// Get serial number
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_SERIAL_NUMBER, out sDeviceInfo);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if(errResult == ErrorCode.SUCCESS)
			{
				objDeviceInfo.SetSerialNumber(sDeviceInfo);
			}

			// Get number of pockets and document processing speed
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_SPEED_POCKET, out sDeviceInfo);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if(errResult == ErrorCode.SUCCESS)
			{
				objDeviceInfo.SetTypeIdB(Encoding.ASCII.GetBytes(sDeviceInfo));
			}
			return ErrorCode.SUCCESS;
		}

		public ErrorCode GetMaintenanceCounterFunction(ref CMaintenanceCounter objMaintenanceCounter)
		{
			if (objMaintenanceCounter == null)
			{
				return ErrorCode.ERR_UNKNOWN;
			}

			ErrorCode errResult = ErrorCode.SUCCESS;
			int nCounter = 0;

			// Lines fed (Roll paper)
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_LINE_FEEDS, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS || errResult == ErrorCode.ERR_PARAM);
			if (errResult == ErrorCode.SUCCESS)
			{
				// S9000
				objMaintenanceCounter.SetLineFeeds(nCounter);
			}
			else if (errResult == ErrorCode.ERR_PARAM)
			{
				// S2000
				objMaintenanceCounter.SetLineFeeds(-1);
			}
			else
			{
				return errResult;
			}

			// Lines fed (Thermal head)
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_LINE_FEEDS, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS || errResult == ErrorCode.ERR_PARAM);
			if (errResult == ErrorCode.SUCCESS)
			{
				// S9000
				objMaintenanceCounter.SetHeadLineFeeds(nCounter);
			}
			else if (errResult == ErrorCode.ERR_PARAM)
			{
				// S2000
				objMaintenanceCounter.SetHeadLineFeeds(-1);
			}
			else
			{
				return errResult;
			}

			// Head shot A
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_SHOT_A, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetHeadShotA(nCounter);
			}
			else
			{
				return errResult;
			}

			// Head shot B
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_SHOT_B, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetHeadShotB(nCounter);
			}
			else
			{
				return errResult;
			}

			// Thermal head energization
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_ENERGIZATION, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS || errResult == ErrorCode.ERR_PARAM);
			if (errResult == ErrorCode.SUCCESS)
			{
				// S9000
				objMaintenanceCounter.SetHeadEnergization(nCounter);
			}
			else if (errResult == ErrorCode.ERR_PARAM)
			{
				// S2000
				objMaintenanceCounter.SetHeadEnergization(-1);
			}
			else
			{
				return errResult;
			}

			// Pump operations
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_PUMP_OPERATION, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetPumpOperation(nCounter);
			}
			else
			{
				return errResult;
			}

			// Auto cutter drive
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_AUTO_CUTTER, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS || errResult == ErrorCode.ERR_PARAM);
			if (errResult == ErrorCode.SUCCESS)
			{
				// S9000
				objMaintenanceCounter.SetAutoCutter(nCounter);
			}
			else if (errResult == ErrorCode.ERR_PARAM)
			{
				// S2000
				objMaintenanceCounter.SetAutoCutter(-1);
			}
			else
			{
				return errResult;
			}

			// Check paper fed
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_ASF_SENDING_OFF, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetAsfSendingOff(nCounter);
			}
			else
			{
				return errResult;
			}

			// Check paper scanned
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_SCANNED_CHECK, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetImageScannedCheckPaper(nCounter);
			}
			else
			{
				return errResult;
			}

			// Card scanned
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_SCANNED_CARD, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetImageScannedCard(nCounter);
			}
			else
			{
				return errResult;
			}

			// MICR reads
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_MICR_READS, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetMicrReads(nCounter);
			}
			else
			{
				return errResult;
			}

			// Pocket switch
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_POCKET_SELECT, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetPocketSelect(nCounter);
			}
			else
			{
				return errResult;
			}

			// Hopper open/close
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HOPPER, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetHopper(nCounter);
			}
			else
			{
				return errResult;
			}

			// Duration of product operation
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_DEVICE_OPERATION_TIME, out nCounter);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult == ErrorCode.SUCCESS)
			{
				objMaintenanceCounter.SetDeviceOperationTime(nCounter);
			}
			else
			{
				return errResult;
			}

			return errResult;
		}
	}
}