#ifndef __INCLUDE_IMAGE_BOX_H__
#define __INCLUDE_IMAGE_BOX_H__

class CImageBox
{
public:
	CStatic	& m_stImageRef;
	HBITMAP   m_hBitmap;
	int       m_nWidth;
	int       m_nHeight;
	CImageBox(CStatic	& stImage) : m_stImageRef(stImage)
	{
		m_hBitmap = NULL;
		m_nWidth = m_nHeight = 0;
	}
	virtual ~CImageBox(void)
	{
	}
	void ClearImage(void)
	{
		if( m_hBitmap != NULL )
		{
			::DeleteObject( m_hBitmap );
			m_hBitmap = NULL;
		}
		m_nWidth = m_nHeight = 0;
	}
	bool SetImage( LPBYTE pDIB, size_t uDIBSize, int nWidth, int nHeight )
	{
		HBITMAP	hBitmap = DIB2HBITMAP( pDIB, uDIBSize, &CClientDC( &m_stImageRef ) );
		if( hBitmap == NULL )
		{
			return false;
		}

		if ( m_hBitmap != NULL )
		{
			(void) ::DeleteObject( m_hBitmap );
		}
		m_hBitmap = hBitmap;
		m_nWidth  = nWidth;
		m_nHeight = nHeight;
		return true;
	}
	bool IsOk(void) const
	{
		if( m_stImageRef.IsWindowVisible() == FALSE )
		{
			return false;
		}

		if( m_hBitmap == NULL )
		{
			// TODO: Add erase code here.
			return false;
		}
		return true;
	}
	void Draw(void)
	{
		if( ! IsOk() )
		{
			return;
		}

		CClientDC dc( & m_stImageRef );
		CDC cdcImageDC;
		RECT rect;
		int nWidth = 0, nHeight = 0;

		if( cdcImageDC.CreateCompatibleDC( &dc ) )
		{
			HGDIOBJ hOld = cdcImageDC.SelectObject( m_hBitmap );

			m_stImageRef.GetClientRect(&rect);
			nWidth  = rect.right  - rect.left;
			nHeight = rect.bottom - rect.top;
			if((m_nWidth * nHeight) < (nWidth * m_nHeight))
			{
				nWidth = nHeight * m_nWidth / m_nHeight;
			} else {
				nHeight = nWidth * m_nHeight / m_nWidth;
			}

			::SetStretchBltMode( dc.GetSafeHdc(), HALFTONE );
			dc.StretchBlt( 0, 0, nWidth, nHeight, &cdcImageDC, 0, 0, m_nWidth, m_nHeight, SRCCOPY );
			cdcImageDC.SelectObject( hOld );

			cdcImageDC.DeleteDC( );
		}
	}
protected:
	HBITMAP	DIB2HBITMAP( LPBYTE pDIB, size_t uDIBSize, CDC * pdcRef )
	{
		if( pDIB == NULL || uDIBSize < sizeof(BITMAPFILEHEADER)+sizeof(BITMAPINFO) )
		{
			return NULL;
		}

		BITMAPFILEHEADER* pBH = reinterpret_cast<BITMAPFILEHEADER*>( pDIB );
		if ( uDIBSize < pBH->bfSize )
		{
			return NULL;
		}

		BITMAPINFO* pBI = reinterpret_cast<BITMAPINFO*>( pDIB + sizeof(BITMAPFILEHEADER) );
		void* pImageData = pDIB + sizeof(BITMAPFILEHEADER) + pBI->bmiHeader.biSize + (pBI->bmiHeader.biClrUsed * sizeof(RGBQUAD));

		return ::CreateDIBitmap( pdcRef->GetSafeHdc(), &(pBI->bmiHeader), CBM_INIT, pImageData, pBI, DIB_RGB_COLORS );
	}
};

#endif//__INCLUDE_IMAGE_BOX_H__
