#include "stdafx.h"
#include "Image_1.h"

CImage_1::CImage_1(void)
{
	m_pCProperty = NULL;
}

CImage_1::~CImage_1(void)
{
}

int CImage_1::Init(CProperty_1* pProperty)
{
	int nResult = SUCCESS;

	m_pCProperty = pProperty;

	GetAPIProcAddress();

	return nResult;
}

// Specify image data format
int CImage_1::SetImageSetting(BYTE byFace, BYTE byLightSource, BYTE byColorDepth, BYTE byFormat)
{
	int nResult = SUCCESS;
	BYTE byColor = EPS_BI_SCN_COLOR;
	BYTE byExOption = EPS_BI_SCN_MANUAL;

	nResult = BiSCNSelectScanFace(m_pCProperty->GetHandle(), byFace);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSelectScanImage(m_pCProperty->GetHandle(), byLightSource);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	if(byColorDepth == EPS_BI_SCN_24BIT)
	{
		byColor = EPS_BI_SCN_COLOR;
		byExOption = EPS_BI_SCN_MANUAL;
	}
	else
	{
		byColor = EPS_BI_SCN_MONOCHROME;
		byExOption = EPS_BI_SCN_SHARP;
	}

	nResult = BiSCNSetImageQuality(m_pCProperty->GetHandle(), byColorDepth, 0, byColor, byExOption);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSetImageFormat(m_pCProperty->GetHandle(), byFormat);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Get check image
int CImage_1::GetScanImage(CImageResult* pImageResult)
{
	int nResult = SUCCESS;
	MF_SCAN* pMfScan = NULL;

	if( pImageResult == NULL )
	{
		return ERR_UNKNOWN;
	}

	nResult = SetImageSetting(
			pImageResult->GetFace(),
			pImageResult->GetLightSource(),
			pImageResult->GetColorDepth(),
			pImageResult->GetFormat());
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	if(pImageResult->GetFace() == MF_SCAN_FACE_FRONT)
	{
		pMfScan = m_pCProperty->GetMfScanFront();
	}
	else
	{
		pMfScan = m_pCProperty->GetMfScanBack();
	}

	pMfScan->sResolution = pImageResult->GetResolution();
	nResult = BiGetScanImage(m_pCProperty->GetHandle(), m_pCProperty->GetTransactionNumber(), pMfScan);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	pImageResult->SetTransactionNumber(m_pCProperty->GetTransactionNumber());
	pImageResult->SetImageSize(pMfScan->dwScanSize);
	pImageResult->SetImage(pMfScan->lpbScanData);
	pImageResult->SetImageWidth (pMfScan->dwXSize);
	pImageResult->SetImageHeight(pMfScan->dwYSize);

	// Obtained image data is not stored in this class
	pMfScan->dwScanSize = 0;
	pMfScan->lpbScanData = NULL;

	return nResult;
}

// Get cashier's check image
int CImage_1::GetCashiersCheckImage(CImageResult* pImageResult)
{
	if( pImageResult == NULL )
	{
		return ERR_UNKNOWN;
	}

	int nResult = SUCCESS;
	MF_SCAN* pMfScan = NULL;

	nResult = BiSCNSelectScanFace(m_pCProperty->GetHandle(), pImageResult->GetFace());
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSelectScanImage(m_pCProperty->GetHandle(), MF_SCAN_IMAGE_VISIBLE);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSetImageQuality(m_pCProperty->GetHandle(), EPS_BI_SCN_24BIT, 0, EPS_BI_SCN_COLOR, EPS_BI_SCN_MANUAL);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSetImageFormat(m_pCProperty->GetHandle(), EPS_BI_SCN_BITMAP);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	if(pImageResult->GetFace() == MF_SCAN_FACE_FRONT)
	{
		pMfScan = m_pCProperty->GetMfScanFront();
	}
	else
	{
		pMfScan = m_pCProperty->GetMfScanBack();
	}

	pMfScan->sResolution = pImageResult->GetResolution();
	nResult = BiGetScanImage(m_pCProperty->GetHandle(), m_pCProperty->GetTransactionNumber(), pMfScan);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	pImageResult->SetTransactionNumber(m_pCProperty->GetTransactionNumber());
	pImageResult->SetImageSize(pMfScan->dwScanSize);
	pImageResult->SetImage(pMfScan->lpbScanData);
	pImageResult->SetImageWidth (pMfScan->dwXSize);
	pImageResult->SetImageHeight(pMfScan->dwYSize);

	// Obtained image data is not stored in this class
	pMfScan->dwScanSize = 0;
	pMfScan->lpbScanData = NULL;

	return nResult;
}

// Get functions of the API
void CImage_1::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_pCProperty->GetLibrary();

	BiSCNSelectScanFace				= (DLL_BiSCNSelectScanFace)				GetProcAddress(hLibrary, "BiSCNSelectScanFace");
	BiSCNSetImageQuality			= (DLL_BiSCNSetImageQuality)			GetProcAddress(hLibrary, "BiSCNSetImageQuality");
	BiSCNSetImageFormat				= (DLL_BiSCNSetImageFormat)				GetProcAddress(hLibrary, "BiSCNSetImageFormat");
	BiGetScanImage					= (DLL_BiGetScanImage)					GetProcAddress(hLibrary, "BiGetScanImage");
	BiSCNSelectScanImage			= (DLL_BiSCNSelectScanImage)			GetProcAddress(hLibrary, "BiSCNSelectScanImage");
}
