#include "stdafx.h"
#include "App.h"

CApp*	g_pApp;

CApp::CApp(void)
{
	// Step 1
	g_pApp					= this;
	m_pFuncProcessErrorCB	= NULL;
	// Step 2
	m_pFuncImageCB			= NULL;
	// Step 3
	m_byExecType			= EXEC_SCAN_CHECK;
	m_pFuncMicrCB			= NULL;
}

CApp::~CApp(void)
{
	ExitDevice();
	g_pApp = NULL;
}

// Initialize
int CApp::InitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetLibrary() == NULL)
	{
		// Load the TM-S9000/S2000 API driver
		HINSTANCE hLibrary = ::LoadLibrary(_T("EpsStmApiWrapper.dll"));
		ASSERT( hLibrary != NULL );
		if(hLibrary == NULL)
		{
			return ERR_LOAD_MODULE;
		}
		m_CCProperty.SetLibrary(hLibrary);
	}

	GetAPIProcAddress();

	if(m_CCProperty.GetHandle() <= 0)
	{
		// Connect to the device
		int nHandle = BiOpenMonPrinter(TYPE_PRINTER, "TM-S9000U,TM-S2000U");
		ASSERT( nHandle > SUCCESS );
		if(nHandle <= 0)
		{
			return nHandle;
		}

		m_CCProperty.SetHandle(nHandle);
	}

	m_CCScan.Init(&m_CCProperty);
	m_CCMicr.Init(&m_CCProperty);
	m_CCOption.Init(&m_CCProperty);
	// Step 2
	m_CCImage.Init(&m_CCProperty);
	// Step 4
	nResult = m_CCEndorse.Init(&m_CCProperty);
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 1
	// Register callback function for notification of the reading status
	nResult = BiSCNMICRSetStatusBackFunction(m_CCProperty.GetHandle(), cbScanStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 4
	// Register callback function for notification of the endorsement data acceptance
	nResult = BiStartEndorsementSetStatusBackFunction(m_CCProperty.GetHandle(), cbStartEndorsement);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Register callback function for notification of the endorsement data close
	nResult = BiEndEndorsementSetStatusBackFunction(m_CCProperty.GetHandle(), cbEndEndorsement);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Post process
int CApp::ExitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetHandle() > 0)
	{
		// Cancel the reading status callback
		nResult = BiSCNMICRCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Step 4
		// Cancel the endorsement data acceptance callback
		nResult = BiStartEndorsementCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Cancel the endorsement data close callback
		nResult = BiEndEndorsementCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Disconnect the device
		nResult = BiCloseMonPrinter(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		m_CCProperty.SetHandle(0);
	}

	if(m_CCProperty.GetLibrary() != NULL)
	{
		// Unload the driver
		::FreeLibrary(m_CCProperty.GetLibrary());
		m_CCProperty.SetLibrary(NULL);
	}

	return nResult;
}

// Step 1
// Register callback function for notification of error during image acquisition
void CApp::SetProcessErrorCallback(PROCESS_ERROR_BACK_FUNC pProcessErrorCB)
{
	m_pFuncProcessErrorCB = pProcessErrorCB;
}

// Step 2
// Register callback function for notification of the image data
void CApp::SetImageCallback(MICR_IMAGE_BACK_FUNC pImageCB)
{
	m_pFuncImageCB = pImageCB;
}

// Step 3
// Register callback function for notification of the MICR data
void CApp::SetMicrCallback(MICR_IMAGE_BACK_FUNC pMicrCB)
{
	m_pFuncMicrCB = pMicrCB;
}

// Set MICR settings
void CApp::SetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		m_CCProperty.SetFont(pMicrParam->GetFont());
		m_CCProperty.SetParsing(pMicrParam->GetParsing());
		m_CCProperty.SetClearSpace(pMicrParam->GetClearSpace());
	}
}

// Get MICR settings
void CApp::GetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		pMicrParam->SetFont(m_CCProperty.GetFont());
		pMicrParam->SetParsing(m_CCProperty.GetParsing());
		pMicrParam->SetClearSpace(m_CCProperty.GetClearSpace());
	}
}

// Step 2
// Set scanning parameters
void CApp::SetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		m_CCProperty.SetScanMedia(pScanParam->GetScanMedia());
		m_CCProperty.SetLightSourceToScan(pScanParam->GetLightSourceToScan());
		m_CCProperty.SetRGBColorDepth(pScanParam->GetRGBColorDepth());
		m_CCProperty.SetIRColorDepth(pScanParam->GetIRColorDepth());
		m_CCProperty.SetResolution(pScanParam->GetResolution());
		m_CCProperty.SetNumberOfDocuments(pScanParam->GetNumberOfDocuments());
	}
}

// Get scanning parameters
void CApp::GetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		pScanParam->SetScanMedia(m_CCProperty.GetScanMedia());
		pScanParam->SetLightSourceToScan(m_CCProperty.GetLightSourceToScan());
		pScanParam->SetRGBColorDepth(m_CCProperty.GetRGBColorDepth());
		pScanParam->SetIRColorDepth(m_CCProperty.GetIRColorDepth());
		pScanParam->SetResolution(m_CCProperty.GetResolution());
		pScanParam->SetNumberOfDocuments(m_CCProperty.GetNumberOfDocuments());
	}
}

// Step 1
// Check scanning process
int CApp::ScanCheck(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CHECK;

	// Step 1
	// Set MF_BASE01 structure
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set check scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MICR reading conditions
	nResult = m_CCMicr.SetMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_PROCESS01 structure
	nResult = m_CCOption.SetProcessSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 4
	// Set endorsement type
	nResult = m_CCEndorse.SetEndorseStation();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start check scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Step 2
// Card scanning process
int CApp::ScanCard(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CARD;

	// Step 2
	// Clear MF_MICR strucuture
	nResult = m_CCMicr.ClearMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_BASE01 strucuture
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set card scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start card scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Check if scanning card with IR in 1 pass is supported.
bool CApp::IsScanningCardIR1PassSupported(void)
{
	int		nResult			= SUCCESS;
	BYTE	DeviceInfo[80]	= {0};
	BYTE	DeviceInfoSize	= _countof(DeviceInfo);

	nResult = BiGetPrnCapability(m_CCProperty.GetHandle(), 112, &DeviceInfoSize, DeviceInfo);
	if(nResult == SUCCESS && DeviceInfoSize >= 1)
	{
		if ( (DeviceInfo[0] & 0x20) == 0x20 )
		{
			return true;
		}
	}
	return false;
}

// Step 3
// Get MICR data
int CApp::GetMicr(CMicrResult* pMicrResult)
{
	return m_CCMicr.GetMicr(pMicrResult);
}

// Get scanned image
int CApp::GetScanImage(CImageResult* pImageResult)
{
	return m_CCImage.GetScanImage(pImageResult);
}

// Error recovery
int CApp::CancelError(void)
{
	return BiCancelError(m_CCProperty.GetHandle());
}

// Get device status
int CApp::GetDeviceStatus(LPDWORD lpStatus)
{
	return BiGetStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Get ink status
int CApp::GetInkStatus(LPWORD lpStatus)
{
	return BiGetInkStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Cancel scanning
int CApp::CancelScan(void)
{
	return m_CCScan.CancelScan();
}

// Step 3
// MICR head cleaning
int CApp::CleaningMicr(void)
{
	return m_CCMicr.CleaningMicr();
}

// Get functions of the API
void CApp::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_CCProperty.GetLibrary();

	// Step 1
	BiOpenMonPrinter				= (DLL_BiOpenMonPrinter)				GetProcAddress(hLibrary, "BiOpenMonPrinter");
	BiCloseMonPrinter				= (DLL_BiCloseMonPrinter)				GetProcAddress(hLibrary, "BiCloseMonPrinter");
	BiSCNMICRSetStatusBackFunction	= (DLL_BiSCNMICRSetStatusBackFunction)	GetProcAddress(hLibrary, "BiSCNMICRSetStatusBackFunction");
	BiSCNMICRCancelStatusBack		= (DLL_BiSCNMICRCancelStatusBack)		GetProcAddress(hLibrary, "BiSCNMICRCancelStatusBack");
	BiCancelError					= (DLL_BiCancelError)					GetProcAddress(hLibrary, "BiCancelError");
	BiGetStatus						= (DLL_BiGetStatus)						GetProcAddress(hLibrary, "BiGetStatus");
	BiGetInkStatus					= (DLL_BiGetInkStatus)					GetProcAddress(hLibrary, "BiGetInkStatus");

	// Step 2
	BiGetPrnCapability				= (DLL_BiGetPrnCapability)				GetProcAddress(hLibrary, "BiGetPrnCapability");

	// Step 4
	BiStartEndorsementSetStatusBackFunction = (DLL_BiStartEndorsementSetStatusBackFunction)	GetProcAddress(hLibrary, "BiStartEndorsementSetStatusBackFunction");
	BiStartEndorsementCancelStatusBack		= (DLL_BiStartEndorsementCancelStatusBack)		GetProcAddress(hLibrary, "BiStartEndorsementCancelStatusBack");
	BiEndEndorsementSetStatusBackFunction	= (DLL_BiEndEndorsementSetStatusBackFunction)	GetProcAddress(hLibrary, "BiEndEndorsementSetStatusBackFunction");
	BiEndEndorsementCancelStatusBack		= (DLL_BiEndEndorsementCancelStatusBack)		GetProcAddress(hLibrary, "BiEndEndorsementCancelStatusBack");
}

// Callback function for notifying scanning status
int CApp::cbScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	return g_pApp->ScanStatus(dwTransactionNumber, wMainStatus, wSubStatus, pPortName);
}

int CApp::ScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	if(wSubStatus != SUCCESS)
	{
		m_pFuncProcessErrorCB( static_cast<short>(wSubStatus) );
	}

	// Step 2
	if(wMainStatus == MF_DATARECEIVE_DONE)
	{
		m_CCProperty.SetTransactionNumber(dwTransactionNumber);

		// Step 4
		if(m_CCProperty.GetEndorseType() == MF_ST_E_ENDORSEMENT)
		{
			// Notify callback for endorsement
			m_pFuncElectronicEndorseCB(dwTransactionNumber);
		}

		// Step 2
		// Notify callback for image data
		m_pFuncImageCB(dwTransactionNumber);

		// Step 3
		if( m_byExecType == EXEC_SCAN_CHECK )
		{
			// Step 3
			// Notify callback for MICR data
			m_pFuncMicrCB(dwTransactionNumber);
		}
	}

	return 0;
}

////////////////
//// Step 4 ////
////////////////

// Set processing mode options
void CApp::SetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 4
		m_CCProperty.SetPrnDataUnreceiveCancel(pOptionParam->GetPrnDataUnreceiveCancel());
		m_CCProperty.SetEndorsePrintMode(pOptionParam->GetEndorsePrintMode());
	}
}

// Get processing mode options
void CApp::GetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 4
		pOptionParam->SetPrnDataUnreceiveCancel(m_CCProperty.GetPrnDataUnreceiveCancel());
		pOptionParam->SetEndorsePrintMode(m_CCProperty.GetEndorsePrintMode());
	}
}

////////////////
//// Step 4 ////
////////////////

// Register callback for Physical Endorsement
void CApp::SetPhysicalEndorseCallback(PHYSICAL_ENDORSE_BACK_FUNC pPhysicalEndorseCB)
{
	m_pFuncPhysicalEndorseCB = pPhysicalEndorseCB;
}

// Register callback for Electronic Endorsement
void CApp::SetElectronicEndorseCallback(ELECTRONIC_ENDORSE_BACK_FUNC pElectronicEndorseCB)
{
	m_pFuncElectronicEndorseCB = pElectronicEndorseCB;
}

// Reading endorsement data file
int CApp::LoadEndorseFile(void)
{
	int nResult = SUCCESS;

	nResult = m_CCEndorse.LoadEndorseFile();

	return nResult;
}

// Set endorsement data
void CApp::SetEndorseParam(CEndorseParam* pEndorseParam)
{
	if(pEndorseParam != NULL)
	{
		m_CCProperty.SetEndorseType       (pEndorseParam->GetEndorseType());
		m_CCProperty.SetEnableEndorsePrint(pEndorseParam->GetEnableEndorsePrint());
		m_CCProperty.SetPayeeEndorse      (pEndorseParam->GetPayeeEndorse());
	}
}

// Get endorsement data
void CApp::GetEndorseParam(CEndorseParam* pEndorseParam)
{
	if(pEndorseParam != NULL)
	{
		pEndorseParam->SetEndorseType       (m_CCProperty.GetEndorseType());
		pEndorseParam->SetEnableEndorsePrint(m_CCProperty.GetEnableEndorsePrint());
		pEndorseParam->SetPayeeEndorse      (m_CCProperty.GetPayeeEndorse());
	}
}

// Set Physical Endorsement data
int CApp::PhysicalEndorseFunction(unsigned long ulTransactionNumber)
{
	int nResult = SUCCESS;

	nResult = m_CCEndorse.PhysicalEndorseFunction(ulTransactionNumber);

	return nResult;
}

// Set Electronic Endorsement data
int CApp::ElectronicEndorseFunction(unsigned long ulTransactionNumber)
{
	int nResult = SUCCESS;

	nResult = m_CCEndorse.ElectronicEndorseFunction(ulTransactionNumber);

	return nResult;
}

// Callback function for notifying endorsement data acceptance
int CApp::cbStartEndorsement(unsigned long ulTransactionNumber, LPSTR lpcPortName)
{
	return g_pApp->StartEndorsement(ulTransactionNumber, lpcPortName);
}

int CApp::StartEndorsement(unsigned long ulTransactionNumber, LPSTR lpcPortName)
{
	if(m_CCProperty.GetEndorseType() == MF_ST_PHYSICAL_ENDORSEMENT)
	{
		// notifying endorsement data acceptance
		m_pFuncPhysicalEndorseCB(ulTransactionNumber);
	}

	return 0;
}

// Callback function for notifying endorsement data close
int CApp::cbEndEndorsement(unsigned long ulTransactionNumber, LPSTR lpcPortName)
{
	return g_pApp->EndEndorsement(ulTransactionNumber, lpcPortName);
}

int CApp::EndEndorsement(unsigned long ulTransactionNumber, LPSTR lpcPortName)
{
	/* After this callback is executed, all endorsement data is discarded */
	return 0;
}
