#include "stdafx.h"
#include "Micr.h"

CMicr::CMicr(void)
{
	m_pCProperty = NULL;
}

CMicr::~CMicr(void)
{
}

int CMicr::Init(CProperty_1* pProperty)
{
	int nResult = SUCCESS;

	m_pCProperty = pProperty;

	GetAPIProcAddress();

	return nResult;
}

// Set MICR reading conditions
int CMicr::SetMicrSetting(void)
{
	int nResult = SUCCESS;
	BOOL bParsing = FALSE;
	BYTE byClearSpaces = CLEAR_SPACE_DISABLE;

	m_pCProperty->GetMfMicr()->iSize = sizeof(MF_MICR01);
	m_pCProperty->GetMfMicr()->iVersion = MF_MICR_VERSION01;

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfMicr(), MF_GET_MICR_DEFAULT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	m_pCProperty->GetMfMicr()->bFont = m_pCProperty->GetFont();
	if(m_pCProperty->GetParsing())
	{
		bParsing = TRUE;
	}
	m_pCProperty->GetMfMicr()->blParsing = bParsing;

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfMicr(), MF_SET_MICR_PARAM);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	if(m_pCProperty->GetClearSpace())
	{
		byClearSpaces = CLEAR_SPACE_ENABLE;
	}

	nResult = BiMICRClearSpaces(m_pCProperty->GetHandle(), byClearSpaces);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Get MICR data
int CMicr::GetMicr(CMicrResult* pMicrResult)
{
	int nResult = SUCCESS;

	if(pMicrResult == NULL)
	{
		return -1;
	}

	nResult = BiGetMicrText(m_pCProperty->GetHandle(), m_pCProperty->GetTransactionNumber(), (MF_MICR*)m_pCProperty->GetMfMicr());
	ASSERT(
			nResult == SUCCESS ||
			nResult == ERR_MICR_BADDATA ||
			nResult == ERR_MICR_NODATA );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	pMicrResult->SetTransactionNumber(m_pCProperty->GetTransactionNumber());
	pMicrResult->SetResult(m_pCProperty->GetMfMicr()->iRet);
	pMicrResult->SetStatus(m_pCProperty->GetMfMicr()->bStatus);
	pMicrResult->SetDetail(m_pCProperty->GetMfMicr()->bDetail);
	pMicrResult->SetMicrStr(m_pCProperty->GetMfMicr()->szMicrStr);
	pMicrResult->SetAccountNumber(m_pCProperty->GetMfMicr()->szAccountNumber);
	pMicrResult->SetAmount(m_pCProperty->GetMfMicr()->szAmount);
	pMicrResult->SetBankNumber(m_pCProperty->GetMfMicr()->szBankNumber);
	pMicrResult->SetSerialNumber(m_pCProperty->GetMfMicr()->szSerialNumber);
	pMicrResult->SetEPC(m_pCProperty->GetMfMicr()->szEPC);
	pMicrResult->SetTransitNumber(m_pCProperty->GetMfMicr()->szTransitNumber);
	pMicrResult->SetCheckType(m_pCProperty->GetMfMicr()->lCheckType);
	pMicrResult->SetCountryCode(m_pCProperty->GetMfMicr()->lCountryCode);
	pMicrResult->SetOnUSField(m_pCProperty->GetMfMicr()->szOnUSField);
	pMicrResult->SetAuxiliatyOnUSField(m_pCProperty->GetMfMicr()->szAuxiliatyOnUsField);

	return nResult;
}

// MICR head cleaning
int CMicr::CleaningMicr(void)
{
	return BiMICRCleaning(m_pCProperty->GetHandle());
}

int CMicr::ClearMicrSetting(void)
{
	return BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfMicr(), MF_CLEAR_MICR_PARAM);
}

// Get functions of the API
void CMicr::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_pCProperty->GetLibrary();

	BiSCNMICRFunctionContinuously	= (DLL_BiSCNMICRFunctionContinuously)	GetProcAddress(hLibrary, "BiSCNMICRFunctionContinuously");
	BiMICRClearSpaces				= (DLL_BiMICRClearSpaces)				GetProcAddress(hLibrary, "BiMICRClearSpaces");
	BiMICRCleaning					= (DLL_BiMICRCleaning)					GetProcAddress(hLibrary, "BiMICRCleaning");
	BiGetMicrText					= (DLL_BiGetMicrText)					GetProcAddress(hLibrary, "BiGetMicrText");
}
