#include "stdafx.h"
#include "Scan.h"

CScan::CScan(void)
{
	m_pCProperty = NULL;
}

CScan::~CScan(void)
{
}

int CScan::Init(CProperty_1* pProperty)
{
	int nResult = SUCCESS;

	m_pCProperty = pProperty;

	GetAPIProcAddress();

	return nResult;
}

// Start scanning
int CScan::ScanFunction(void)
{
	int nResult = SUCCESS;

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), NULL, MF_EXEC);
	ASSERT( nResult == SUCCESS );

	return nResult;
}

// Set MF_BASE01 structure
int CScan::SetBaseSetting(void)
{
	int nResult = SUCCESS;

	nResult = BiSCNSelectScanUnit(m_pCProperty->GetHandle(), m_pCProperty->GetScanMedia());
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 2
	nResult = BiSetNumberOfDocuments(m_pCProperty->GetHandle(), m_pCProperty->GetNumberOfDocuments());
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 1
	m_pCProperty->GetMfBase01()->iSize			= sizeof(MF_BASE01);
	m_pCProperty->GetMfBase01()->iVersion		= MF_BASE_VERSION01;

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfBase01(), MF_GET_BASE_DEFAULT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	m_pCProperty->GetMfBase01()->wErrorEject	= MF_EXIT_ERROR_DISCHARGE;

	// Set buzzer settings
	if( m_pCProperty->GetBuzzerSuccess() == true )
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_SUCCESS] = BUZZER_COUNT_SUCCESS;
		m_pCProperty->GetMfBase01()->bBuzzerHz[MF_BUZZER_TYPE_SUCCESS] = MF_BUZZER_HZ_4000;
	}
	else
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_SUCCESS] = MF_BUZZER_DISABLE;
	}

	if( m_pCProperty->GetBuzzerError() == true )
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_ERROR] = BUZZER_COUNT_ERROR;
		m_pCProperty->GetMfBase01()->bBuzzerHz[MF_BUZZER_TYPE_ERROR] = MF_BUZZER_HZ_880;
	}
	else
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_ERROR] = MF_BUZZER_DISABLE;
	}

	if( m_pCProperty->GetBuzzerDoubleFeed() == true )
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_WFEED] = BUUZER_COUNT_WFEED;
		m_pCProperty->GetMfBase01()->bBuzzerHz[MF_BUZZER_TYPE_WFEED] = MF_BUZZER_HZ_440;
	}
	else
	{
		m_pCProperty->GetMfBase01()->bBuzzerCount[MF_BUZZER_TYPE_WFEED] = MF_BUZZER_DISABLE;
	}

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfBase01(), MF_SET_BASE_PARAM);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Set scanning conditions
int CScan::SetScanSetting(void)
{
	int nResult = SUCCESS;

	// For front side image
	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfScanFront(), MF_GET_SCAN_FRONT_DEFAULT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	m_pCProperty->GetMfScanFront()->iSize		= sizeof(MF_SCAN);
	m_pCProperty->GetMfScanFront()->iVersion	= MF_SCAN_VERSION;
	m_pCProperty->GetMfScanFront()->sResolution = m_pCProperty->GetResolution();

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfScanFront(), MF_SET_SCAN_FRONT_PARAM);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSelectScanFace(m_pCProperty->GetHandle(), MF_SCAN_FACE_FRONT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSetImageTypeOption(m_pCProperty->GetHandle(), m_pCProperty->GetLightSourceToScan());
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// For back side image
	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfScanBack(), MF_GET_SCAN_BACK_DEFAULT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	m_pCProperty->GetMfScanBack()->iSize = sizeof(MF_SCAN);
	m_pCProperty->GetMfScanBack()->iVersion = MF_SCAN_VERSION;
	m_pCProperty->GetMfScanBack()->sResolution = m_pCProperty->GetResolution();

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfScanBack(), MF_SET_SCAN_BACK_PARAM);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSelectScanFace(m_pCProperty->GetHandle(), MF_SCAN_FACE_BACK);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiSCNSetImageTypeOption(m_pCProperty->GetHandle(), m_pCProperty->GetLightSourceToScan());
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Scanning cancellation
int CScan::CancelScan(void)
{
	return BiSCNMICRCancelFunction(m_pCProperty->GetHandle(), MF_EJECT_DISCHARGE);
}

// Get functions of the API
void CScan::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_pCProperty->GetLibrary();

	BiSCNSelectScanUnit				= (DLL_BiSCNSelectScanUnit)				GetProcAddress(hLibrary, "BiSCNSelectScanUnit");
	BiSetNumberOfDocuments			= (DLL_BiSetNumberOfDocuments)			GetProcAddress(hLibrary, "BiSetNumberOfDocuments");
	BiSCNMICRFunctionContinuously	= (DLL_BiSCNMICRFunctionContinuously)	GetProcAddress(hLibrary, "BiSCNMICRFunctionContinuously");
	BiSCNMICRCancelFunction			= (DLL_BiSCNMICRCancelFunction)			GetProcAddress(hLibrary, "BiSCNMICRCancelFunction");
	BiSCNSetImageTypeOption			= (DLL_BiSCNSetImageTypeOption)			GetProcAddress(hLibrary, "BiSCNSetImageTypeOption");
	BiSCNSelectScanFace				= (DLL_BiSCNSelectScanFace)				GetProcAddress(hLibrary, "BiSCNSelectScanFace");
}
