#include "stdafx.h"
#include "App.h"

CApp*	g_pApp;

CApp::CApp(void)
{
	// Step 1
	g_pApp					= this;
	m_pFuncProcessErrorCB	= NULL;
	// Step 2
	m_pFuncImageCB			= NULL;
	// Step 3
	m_byExecType			= EXEC_SCAN_CHECK;
	m_pFuncMicrCB			= NULL;
	// Step 7
	m_pFuncIqaCB			= NULL;
	m_pFuncConfirmationCB	= NULL;
}

CApp::~CApp(void)
{
	ExitDevice();
	g_pApp = NULL;
}

// Initialize
int CApp::InitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetLibrary() == NULL)
	{
		// Load the TM-S9000/S2000 API driver
		HINSTANCE hLibrary = ::LoadLibrary(_T("EpsStmApiWrapper.dll"));
		ASSERT( hLibrary != NULL );
		if(hLibrary == NULL)
		{
			return ERR_LOAD_MODULE;
		}
		m_CCProperty.SetLibrary(hLibrary);
	}

	GetAPIProcAddress();

	if(m_CCProperty.GetHandle() <= 0)
	{
		// Connect to the device
		int nHandle = BiOpenMonPrinter(TYPE_PRINTER, "TM-S9000U,TM-S2000U");
		ASSERT( nHandle > SUCCESS );
		if(nHandle <= 0)
		{
			return nHandle;
		}

		m_CCProperty.SetHandle(nHandle);
	}

	m_CCScan.Init(&m_CCProperty);
	m_CCMicr.Init(&m_CCProperty);
	m_CCOption.Init(&m_CCProperty);
	// Step 2
	m_CCImage.Init(&m_CCProperty);
	// Step 7
	m_CCIqa.Init(&m_CCProperty);

	// Step 1
	// Register callback function for notification of the reading status
	nResult = BiSCNMICRSetStatusBackFunction(m_CCProperty.GetHandle(), cbScanStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Post process
int CApp::ExitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetHandle() > 0)
	{
		// Cancel the reading status callback
		nResult = BiSCNMICRCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Disconnect the device
		nResult = BiCloseMonPrinter(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		m_CCProperty.SetHandle(0);
	}

	if(m_CCProperty.GetLibrary() != NULL)
	{
		// Unload the driver
		::FreeLibrary(m_CCProperty.GetLibrary());
		m_CCProperty.SetLibrary(NULL);
	}

	return nResult;
}

// Step 1
// Register callback function for notification of error during image acquisition
void CApp::SetProcessErrorCallback(PROCESS_ERROR_BACK_FUNC pProcessErrorCB)
{
	m_pFuncProcessErrorCB = pProcessErrorCB;
}

// Step 2
// Register callback function for notification of the image data
void CApp::SetImageCallback(MICR_IMAGE_BACK_FUNC pImageCB)
{
	m_pFuncImageCB = pImageCB;
}

// Step 3
// Register callback function for notification of the MICR data
void CApp::SetMicrCallback(MICR_IMAGE_BACK_FUNC pMicrCB)
{
	m_pFuncMicrCB = pMicrCB;
}

// Set MICR settings
void CApp::SetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		m_CCProperty.SetFont(pMicrParam->GetFont());
		m_CCProperty.SetParsing(pMicrParam->GetParsing());
		m_CCProperty.SetClearSpace(pMicrParam->GetClearSpace());
	}
}

// Get MICR settings
void CApp::GetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		pMicrParam->SetFont(m_CCProperty.GetFont());
		pMicrParam->SetParsing(m_CCProperty.GetParsing());
		pMicrParam->SetClearSpace(m_CCProperty.GetClearSpace());
	}
}

// Step 2
// Set scanning parameters
void CApp::SetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		m_CCProperty.SetScanMedia(pScanParam->GetScanMedia());
		m_CCProperty.SetLightSourceToScan(pScanParam->GetLightSourceToScan());
		m_CCProperty.SetRGBColorDepth(pScanParam->GetRGBColorDepth());
		m_CCProperty.SetIRColorDepth(pScanParam->GetIRColorDepth());
		m_CCProperty.SetResolution(pScanParam->GetResolution());
		m_CCProperty.SetNumberOfDocuments(pScanParam->GetNumberOfDocuments());
	}
}

// Get scanning parameters
void CApp::GetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		pScanParam->SetScanMedia(m_CCProperty.GetScanMedia());
		pScanParam->SetLightSourceToScan(m_CCProperty.GetLightSourceToScan());
		pScanParam->SetRGBColorDepth(m_CCProperty.GetRGBColorDepth());
		pScanParam->SetIRColorDepth(m_CCProperty.GetIRColorDepth());
		pScanParam->SetResolution(m_CCProperty.GetResolution());
		pScanParam->SetNumberOfDocuments(m_CCProperty.GetNumberOfDocuments());
	}
}

// Step 1
// Check scanning process
int CApp::ScanCheck(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CHECK;

	// Step 1
	// Set MF_BASE01 structure
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set check scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MICR reading conditions
	nResult = m_CCMicr.SetMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_PROCESS01 structure
	nResult = m_CCOption.SetProcessSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 7
	// Set water fall mode
	nResult = m_CCOption.SetWaterfallMode();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 7
	// Set IQA test conditions
	nResult = m_CCIqa.SetIqaSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start check scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Step 2
// Card scanning process
int CApp::ScanCard(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CARD;

	// Step 2
	// Clear MF_MICR strucuture
	nResult = m_CCMicr.ClearMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_BASE01 strucuture
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set card scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start card scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Check if scanning card with IR in 1 pass is supported.
bool CApp::IsScanningCardIR1PassSupported(void)
{
	int		nResult			= SUCCESS;
	BYTE	DeviceInfo[80]	= {0};
	BYTE	DeviceInfoSize	= _countof(DeviceInfo);

	nResult = BiGetPrnCapability(m_CCProperty.GetHandle(), 112, &DeviceInfoSize, DeviceInfo);
	if(nResult == SUCCESS && DeviceInfoSize >= 1)
	{
		if ( (DeviceInfo[0] & 0x20) == 0x20 )
		{
			return true;
		}
	}
	return false;
}

// Step 3
// Get MICR data
int CApp::GetMicr(CMicrResult* pMicrResult)
{
	return m_CCMicr.GetMicr(pMicrResult);
}

// Get scanned image
int CApp::GetScanImage(CImageResult* pImageResult)
{
	return m_CCImage.GetScanImage(pImageResult);
}

// Error recovery
int CApp::CancelError(void)
{
	return BiCancelError(m_CCProperty.GetHandle());
}

// Get device status
int CApp::GetDeviceStatus(LPDWORD lpStatus)
{
	return BiGetStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Get ink status
int CApp::GetInkStatus(LPWORD lpStatus)
{
	return BiGetInkStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Cancel scanning
int CApp::CancelScan(void)
{
	return m_CCScan.CancelScan();
}

// Step 3
// MICR head cleaning
int CApp::CleaningMicr(void)
{
	return m_CCMicr.CleaningMicr();
}

// Get functions of the API
void CApp::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_CCProperty.GetLibrary();

	// Step 1
	BiOpenMonPrinter				= (DLL_BiOpenMonPrinter)				GetProcAddress(hLibrary, "BiOpenMonPrinter");
	BiCloseMonPrinter				= (DLL_BiCloseMonPrinter)				GetProcAddress(hLibrary, "BiCloseMonPrinter");
	BiSCNMICRSetStatusBackFunction	= (DLL_BiSCNMICRSetStatusBackFunction)	GetProcAddress(hLibrary, "BiSCNMICRSetStatusBackFunction");
	BiSCNMICRCancelStatusBack		= (DLL_BiSCNMICRCancelStatusBack)		GetProcAddress(hLibrary, "BiSCNMICRCancelStatusBack");
	BiCancelError					= (DLL_BiCancelError)					GetProcAddress(hLibrary, "BiCancelError");
	BiGetStatus						= (DLL_BiGetStatus)						GetProcAddress(hLibrary, "BiGetStatus");
	BiGetInkStatus					= (DLL_BiGetInkStatus)					GetProcAddress(hLibrary, "BiGetInkStatus");

	// Step 2
	BiGetPrnCapability				= (DLL_BiGetPrnCapability)				GetProcAddress(hLibrary, "BiGetPrnCapability");
}

// Callback function for notifying scanning status
int CApp::cbScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	return g_pApp->ScanStatus(dwTransactionNumber, wMainStatus, wSubStatus, pPortName);
}

int CApp::ScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	if(wSubStatus != SUCCESS)
	{
		m_pFuncProcessErrorCB( static_cast<short>(wSubStatus) );
	}

	// Step 2
	if(wMainStatus == MF_DATARECEIVE_DONE)
	{
		m_CCProperty.SetTransactionNumber(dwTransactionNumber);

		// Step 2
		// Notify callback for image data
		m_pFuncImageCB(dwTransactionNumber);

		// Step 3
		if( m_byExecType == EXEC_SCAN_CHECK )
		{
			// Step 3
			// Notify callback for MICR data
			m_pFuncMicrCB(dwTransactionNumber);

			// Step 7
			// Notify callback for IQA test
			m_pFuncIqaCB();
		}

		// Step 7
		if( m_byExecType == EXEC_SCAN_CHECK &&
			m_CCProperty.GetActivation() == MF_ACTIVATE_MODE_CONFIRMATION )
		{
			// notify callback for scanning in confirmatio mode
			m_pFuncConfirmationCB();
		}
	}

	return 0;
}

////////////////
//// Step 7 ////
////////////////

// Set processing mode options
void CApp::SetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 7
		m_CCProperty.SetActivation(pOptionParam->GetActivation());
		m_CCProperty.SetWaterfall(pOptionParam->GetWaterfall());
	}
}

// Get processing mode options
void CApp::GetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 7
		pOptionParam->SetActivation(m_CCProperty.GetActivation());
		pOptionParam->SetWaterfall(m_CCProperty.GetWaterfall());
	}
}

// Register callback for scanning in confirmation mode
void CApp::SetConfirmationCallback(CONFIRMATION_BACK_FUNC pConfirmationCB)
{
	m_pFuncConfirmationCB = pConfirmationCB;
}

////////////////
//// Step 7 ////
////////////////

// Set settings in confirmation mode
void CApp::SetConfirmationParam(COptionParam *pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 7
		m_CCProperty.SetConfirmationEject(pOptionParam->GetConfirmationEject());
		m_CCProperty.SetConfirmationCancel(pOptionParam->GetConfirmationCancel());
	}
}

// Perform confirmation mode processing
int CApp::ConfirmationFunction(void)
{
	return m_CCOption.ConfirmationFunction();
}

////////////////
//// Step 7 ////
////////////////

// Register callback for obtaining IQA result
void CApp::SetIqaCallback(IQA_RESULT_BACK_FUNC pIqaCB)
{
	m_pFuncIqaCB = pIqaCB;
}

// Set IQA test conditions
void CApp::SetIqaParam(CIqaParam* pIqaParam)
{
	if( pIqaParam != NULL)
	{
		m_CCProperty.SetIqaDetect(pIqaParam->GetIqaDetect());
		m_CCProperty.SetIqaCancel(pIqaParam->GetIqaCancel());
		m_CCProperty.SetIqaEjectPocket(pIqaParam->GetIqaEjectPocket());
		m_CCProperty.SetIqaColorDepth(pIqaParam->GetIqaColorDepth());
		m_CCProperty.SetUnderSize(pIqaParam->GetUnderSize());
		m_CCProperty.SetOverSize(pIqaParam->GetOverSize());
		m_CCProperty.SetMinCompressed(pIqaParam->GetMinCompressed());
		m_CCProperty.SetMaxCompressed(pIqaParam->GetMaxCompressed());
		m_CCProperty.SetFrontRearImageMismatch(pIqaParam->GetFrontRearImageMismatch());
		m_CCProperty.SetImageTooLight(pIqaParam->GetImageTooLight());
		m_CCProperty.SetImageTooDark(pIqaParam->GetImageTooDark());
		m_CCProperty.SetHorizontalStreaksPresent(pIqaParam->GetHorizontalStreaksPresent());
		m_CCProperty.SetSpotNoise(pIqaParam->GetSpotNoise());
		m_CCProperty.SetOutOfFocus(pIqaParam->GetOutOfFocus());
		m_CCProperty.SetFoldedTornCorner(pIqaParam->GetFoldedTornCorner());
		m_CCProperty.SetFoldedTornEdge(pIqaParam->GetFoldedTornEdge());
		m_CCProperty.SetFramingError(pIqaParam->GetFramingError());
		m_CCProperty.SetExcessiveSkew(pIqaParam->GetExcessiveSkew());
		m_CCProperty.SetCarbonStripDetection(pIqaParam->GetCarbonStripDetection());
		m_CCProperty.SetPiggyback(pIqaParam->GetPiggyback());
	}
}

// Obtain IQA test result
void CApp::GetIqaParam(CIqaParam* pIqaParam)
{
	if(pIqaParam != NULL)
	{
		pIqaParam->SetIqaDetect(m_CCProperty.GetIqaDetect());
		pIqaParam->SetIqaCancel(m_CCProperty.GetIqaCancel());
		pIqaParam->SetIqaEjectPocket(m_CCProperty.GetIqaEjectPocket());
		pIqaParam->SetIqaColorDepth(m_CCProperty.GetIqaColorDepth());
		pIqaParam->SetUnderSize(m_CCProperty.GetUnderSize());
		pIqaParam->SetOverSize(m_CCProperty.GetOverSize());
		pIqaParam->SetMinCompressed(m_CCProperty.GetMinCompressed());
		pIqaParam->SetMaxCompressed(m_CCProperty.GetMaxCompressed());
		pIqaParam->SetFrontRearImageMismatch(m_CCProperty.GetFrontRearImageMismatch());
		pIqaParam->SetImageTooLight(m_CCProperty.GetImageTooLight());
		pIqaParam->SetImageTooDark(m_CCProperty.GetImageTooDark());
		pIqaParam->SetHorizontalStreaksPresent(m_CCProperty.GetHorizontalStreaksPresent());
		pIqaParam->SetSpotNoise(m_CCProperty.GetSpotNoise());
		pIqaParam->SetOutOfFocus(m_CCProperty.GetOutOfFocus());
		pIqaParam->SetFoldedTornCorner(m_CCProperty.GetFoldedTornCorner());
		pIqaParam->SetFoldedTornEdge(m_CCProperty.GetFoldedTornEdge());
		pIqaParam->SetFramingError(m_CCProperty.GetFramingError());
		pIqaParam->SetExcessiveSkew(m_CCProperty.GetExcessiveSkew());
		pIqaParam->SetCarbonStripDetection(m_CCProperty.GetCarbonStripDetection());
		pIqaParam->SetPiggyback(m_CCProperty.GetPiggyback());
	}
}

// Get IQA test result
int CApp::GetIqaResult(CIqaResult *pIqaResult)
{
	return m_CCIqa.GetIqa(pIqaResult);
}
