#include "stdafx.h"
#include "App.h"

CApp*	g_pApp;

CApp::CApp(void)
{
	// Step 1
	g_pApp					= this;
	m_pFuncProcessErrorCB	= NULL;
	// Step 2
	m_pFuncImageCB			= NULL;
	// Step 3
	m_byExecType			= EXEC_SCAN_CHECK;
	m_pFuncMicrCB			= NULL;
	// Step 8
	m_pFuncDeviceStatusCB	= NULL;
	m_pFuncInkStatusCB		= NULL;
}

CApp::~CApp(void)
{
	ExitDevice();
	g_pApp = NULL;
}

// Initialize
int CApp::InitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetLibrary() == NULL)
	{
		// Load the TM-S9000/S2000 API driver
		HINSTANCE hLibrary = ::LoadLibrary(_T("EpsStmApiWrapper.dll"));
		ASSERT( hLibrary != NULL );
		if(hLibrary == NULL)
		{
			return ERR_LOAD_MODULE;
		}
		m_CCProperty.SetLibrary(hLibrary);
	}

	GetAPIProcAddress();

	if(m_CCProperty.GetHandle() <= 0)
	{
		// Connect to the device
		int nHandle = BiOpenMonPrinter(TYPE_PRINTER, "TM-S9000U,TM-S2000U");
		ASSERT( nHandle > SUCCESS );
		if(nHandle <= 0)
		{
			return nHandle;
		}

		m_CCProperty.SetHandle(nHandle);
	}

	m_CCScan.Init(&m_CCProperty);
	m_CCMicr.Init(&m_CCProperty);
	m_CCOption.Init(&m_CCProperty);
	// Step 2
	m_CCImage.Init(&m_CCProperty);
	// Step 8
	m_CCBarcode.Init(&m_CCProperty);
	m_CCInfo.Init(&m_CCProperty);

	// Step 1
	// Register callback function for notification of the reading status
	nResult = BiSCNMICRSetStatusBackFunction(m_CCProperty.GetHandle(), cbScanStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 8
	// Register callback function for notification of the device status
	nResult = BiSetStatusBackFunction(m_CCProperty.GetHandle(), cbStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Register callback function for notification of ink status
	nResult = BiSetInkStatusBackFunction(m_CCProperty.GetHandle(), cbInkStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Post process
int CApp::ExitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetHandle() > 0)
	{
		// Cancel the reading status callback
		nResult = BiSCNMICRCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Step 8
		// Cancel the device status callback
		nResult = BiCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Cancel the ink status callback
		nResult = BiCancelInkStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Disconnect the device
		nResult = BiCloseMonPrinter(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		m_CCProperty.SetHandle(0);
	}

	if(m_CCProperty.GetLibrary() != NULL)
	{
		// Unload the driver
		::FreeLibrary(m_CCProperty.GetLibrary());
		m_CCProperty.SetLibrary(NULL);
	}

	return nResult;
}

// Step 1
// Register callback function for notification of error during image acquisition
void CApp::SetProcessErrorCallback(PROCESS_ERROR_BACK_FUNC pProcessErrorCB)
{
	m_pFuncProcessErrorCB = pProcessErrorCB;
}

// Step 2
// Register callback function for notification of the image data
void CApp::SetImageCallback(MICR_IMAGE_BACK_FUNC pImageCB)
{
	m_pFuncImageCB = pImageCB;
}

// Step 3
// Register callback function for notification of the MICR data
void CApp::SetMicrCallback(MICR_IMAGE_BACK_FUNC pMicrCB)
{
	m_pFuncMicrCB = pMicrCB;
}

// Set MICR settings
void CApp::SetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		m_CCProperty.SetFont(pMicrParam->GetFont());
		m_CCProperty.SetParsing(pMicrParam->GetParsing());
		m_CCProperty.SetClearSpace(pMicrParam->GetClearSpace());
	}
}

// Get MICR settings
void CApp::GetMicrParam(CMicrParam* pMicrParam)
{
	if(pMicrParam != NULL)
	{
		pMicrParam->SetFont(m_CCProperty.GetFont());
		pMicrParam->SetParsing(m_CCProperty.GetParsing());
		pMicrParam->SetClearSpace(m_CCProperty.GetClearSpace());
	}
}

// Step 2
// Set scanning parameters
void CApp::SetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		m_CCProperty.SetScanMedia(pScanParam->GetScanMedia());
		m_CCProperty.SetLightSourceToScan(pScanParam->GetLightSourceToScan());
		m_CCProperty.SetRGBColorDepth(pScanParam->GetRGBColorDepth());
		m_CCProperty.SetIRColorDepth(pScanParam->GetIRColorDepth());
		m_CCProperty.SetResolution(pScanParam->GetResolution());
		m_CCProperty.SetNumberOfDocuments(pScanParam->GetNumberOfDocuments());
	}
}

// Get scanning parameters
void CApp::GetScanParam(CScanParam* pScanParam)
{
	if(pScanParam != NULL)
	{
		pScanParam->SetScanMedia(m_CCProperty.GetScanMedia());
		pScanParam->SetLightSourceToScan(m_CCProperty.GetLightSourceToScan());
		pScanParam->SetRGBColorDepth(m_CCProperty.GetRGBColorDepth());
		pScanParam->SetIRColorDepth(m_CCProperty.GetIRColorDepth());
		pScanParam->SetResolution(m_CCProperty.GetResolution());
		pScanParam->SetNumberOfDocuments(m_CCProperty.GetNumberOfDocuments());
	}
}

// Step 1
// Check scanning process
int CApp::ScanCheck(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CHECK;

	// Step 1
	// Set MF_BASE01 structure
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set check scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MICR reading conditions
	nResult = m_CCMicr.SetMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_PROCESS01 structure
	nResult = m_CCOption.SetProcessSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Step 8
	// Set barcode recoginition conditions
	nResult = m_CCBarcode.SetBarcodeSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start check scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Step 2
// Card scanning process
int CApp::ScanCard(void)
{
	int nResult = SUCCESS;

	// Step 3
	m_byExecType = EXEC_SCAN_CARD;

	// Step 2
	// Clear MF_MICR strucuture
	nResult = m_CCMicr.ClearMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_BASE01 strucuture
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set card scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start card scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Check if scanning card with IR in 1 pass is supported.
bool CApp::IsScanningCardIR1PassSupported(void)
{
	int		nResult			= SUCCESS;
	BYTE	DeviceInfo[80]	= {0};
	BYTE	DeviceInfoSize	= _countof(DeviceInfo);

	nResult = BiGetPrnCapability(m_CCProperty.GetHandle(), 112, &DeviceInfoSize, DeviceInfo);
	if(nResult == SUCCESS && DeviceInfoSize >= 1)
	{
		if ( (DeviceInfo[0] & 0x20) == 0x20 )
		{
			return true;
		}
	}
	return false;
}

// Step 3
// Get MICR data
int CApp::GetMicr(CMicrResult* pMicrResult)
{
	return m_CCMicr.GetMicr(pMicrResult);
}

// Get scanned image
int CApp::GetScanImage(CImageResult* pImageResult)
{
	return m_CCImage.GetScanImage(pImageResult);
}

// Error recovery
int CApp::CancelError(void)
{
	return BiCancelError(m_CCProperty.GetHandle());
}

// Get device status
int CApp::GetDeviceStatus(LPDWORD lpStatus)
{
	return BiGetStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Get ink status
int CApp::GetInkStatus(LPWORD lpStatus)
{
	return BiGetInkStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Cancel scanning
int CApp::CancelScan(void)
{
	return m_CCScan.CancelScan();
}

// Step 3
// MICR head cleaning
int CApp::CleaningMicr(void)
{
	return m_CCMicr.CleaningMicr();
}

// Get functions of the API
void CApp::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_CCProperty.GetLibrary();

	// Step 1
	BiOpenMonPrinter				= (DLL_BiOpenMonPrinter)				GetProcAddress(hLibrary, "BiOpenMonPrinter");
	BiCloseMonPrinter				= (DLL_BiCloseMonPrinter)				GetProcAddress(hLibrary, "BiCloseMonPrinter");
	BiSCNMICRSetStatusBackFunction	= (DLL_BiSCNMICRSetStatusBackFunction)	GetProcAddress(hLibrary, "BiSCNMICRSetStatusBackFunction");
	BiSCNMICRCancelStatusBack		= (DLL_BiSCNMICRCancelStatusBack)		GetProcAddress(hLibrary, "BiSCNMICRCancelStatusBack");
	BiCancelError					= (DLL_BiCancelError)					GetProcAddress(hLibrary, "BiCancelError");
	BiGetStatus						= (DLL_BiGetStatus)						GetProcAddress(hLibrary, "BiGetStatus");
	BiGetInkStatus					= (DLL_BiGetInkStatus)					GetProcAddress(hLibrary, "BiGetInkStatus");

	// Step 2
	BiGetPrnCapability				= (DLL_BiGetPrnCapability)				GetProcAddress(hLibrary, "BiGetPrnCapability");

	// Step 8
	BiSetStatusBackFunction			= (DLL_BiSetStatusBackFunction)			GetProcAddress(hLibrary, "BiSetStatusBackFunction");
	BiSetInkStatusBackFunction		= (DLL_BiSetInkStatusBackFunction)		GetProcAddress(hLibrary, "BiSetInkStatusBackFunction");
	BiCancelStatusBack				= (DLL_BiCancelStatusBack)				GetProcAddress(hLibrary, "BiCancelStatusBack");
	BiCancelInkStatusBack			= (DLL_BiCancelInkStatusBack)			GetProcAddress(hLibrary, "BiCancelInkStatusBack");
}

// Callback function for notifying scanning status
int CApp::cbScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	return g_pApp->ScanStatus(dwTransactionNumber, wMainStatus, wSubStatus, pPortName);
}

int CApp::ScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	if(wSubStatus != SUCCESS)
	{
		m_pFuncProcessErrorCB( static_cast<short>(wSubStatus) );
	}

	// Step 2
	if(wMainStatus == MF_DATARECEIVE_DONE)
	{
		m_CCProperty.SetTransactionNumber(dwTransactionNumber);

		// Step 2
		// Notify callback for image data
		m_pFuncImageCB(dwTransactionNumber);

		// Step 3
		if( m_byExecType == EXEC_SCAN_CHECK )
		{
			// Step 3
			// Notify callback for MICR data
			m_pFuncMicrCB(dwTransactionNumber);

			// Step 8
			// Notify callback for barcode data
			m_pFuncBarcodeCB();
		}
	}

	return 0;
}

////////////////
//// Step 8 ////
////////////////

// Set processing mode options
void CApp::SetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		// Step 8
		m_CCProperty.SetPaperMisInsertionDetect(pOptionParam->GetPaperMisInsertionDetect());
		m_CCProperty.SetPaperMisInsertionCancel(pOptionParam->GetPaperMisInsertionCancel());
		m_CCProperty.SetPaperMisInsertionEject(pOptionParam->GetPaperMisInsertionEject());
		m_CCProperty.SetNoiseDetect(pOptionParam->GetNoiseDetect());
		m_CCProperty.SetNoiseCancel(pOptionParam->GetNoiseCancel());
		m_CCProperty.SetNoiseEject(pOptionParam->GetNoiseEject());
		m_CCProperty.SetDoubleFeedDetect(pOptionParam->GetDoubleFeedDetect());
		m_CCProperty.SetDoubleFeedCancel(pOptionParam->GetDoubleFeedCancel());
		m_CCProperty.SetDoubleFeedEject(pOptionParam->GetDoubleFeedEject());
		m_CCProperty.SetBaddataDetect(pOptionParam->GetBaddataDetect());
		m_CCProperty.SetBaddataCancel(pOptionParam->GetBaddataCancel());
		m_CCProperty.SetBaddataEject(pOptionParam->GetBaddataEject());
		m_CCProperty.SetNodataDetect(pOptionParam->GetNodataDetect());
		m_CCProperty.SetNodataCancel(pOptionParam->GetNodataCancel());
		m_CCProperty.SetNodataEject(pOptionParam->GetNodataEject());
	}
}

// Get processing mode options
void CApp::GetOptionParam(COptionParam* pOptionParam)
{
	if(pOptionParam != NULL)
	{
		pOptionParam->SetPaperMisInsertionDetect(m_CCProperty.GetPaperMisInsertionDetect());
		pOptionParam->SetPaperMisInsertionCancel(m_CCProperty.GetPaperMisInsertionCancel());
		pOptionParam->SetPaperMisInsertionEject(m_CCProperty.GetPaperMisInsertionEject());
		pOptionParam->SetNoiseDetect(m_CCProperty.GetNoiseDetect());
		pOptionParam->SetNoiseCancel(m_CCProperty.GetNoiseCancel());
		pOptionParam->SetNoiseEject(m_CCProperty.GetNoiseEject());
		pOptionParam->SetDoubleFeedDetect(m_CCProperty.GetDoubleFeedDetect());
		pOptionParam->SetDoubleFeedCancel(m_CCProperty.GetDoubleFeedCancel());
		pOptionParam->SetDoubleFeedEject(m_CCProperty.GetDoubleFeedEject());
		pOptionParam->SetBaddataDetect(m_CCProperty.GetBaddataDetect());
		pOptionParam->SetBaddataCancel(m_CCProperty.GetBaddataCancel());
		pOptionParam->SetBaddataEject(m_CCProperty.GetBaddataEject());
		pOptionParam->SetNodataDetect(m_CCProperty.GetNodataDetect());
		pOptionParam->SetNodataCancel(m_CCProperty.GetNodataCancel());
		pOptionParam->SetNodataEject(m_CCProperty.GetNodataEject());
	}
}

////////////////
//// Step 8 ////
////////////////

// Set barcode recognition settings
void CApp::SetBarcodeParam(CBarcodeParam* pBarcodeParam)
{
	if(pBarcodeParam != NULL)
	{
		m_CCProperty.SetBarcodeTypeMask(pBarcodeParam->GetBarcodeTypeMask());
		m_CCProperty.SetBarcodeDetect(pBarcodeParam->GetBarcodeDetect());
		m_CCProperty.SetBarcodeCancel(pBarcodeParam->GetBarcodeCancel());
		m_CCProperty.SetBarcodeEject(pBarcodeParam->GetBarcodeEject());
	}
}

// Get barcode recognition settings
void CApp::GetBarcodeParam(CBarcodeParam* pBarcodeParam)
{
	if(pBarcodeParam != NULL)
	{
		pBarcodeParam->SetBarcodeTypeMask(m_CCProperty.GetBarcodeTypeMask());
		pBarcodeParam->SetBarcodeDetect(m_CCProperty.GetBarcodeDetect());
		pBarcodeParam->SetBarcodeCancel(m_CCProperty.GetBarcodeCancel());
		pBarcodeParam->SetBarcodeEject(m_CCProperty.GetBarcodeEject());
	}
}

// Regsiter callback function for barcode recognition
void CApp::SetBarcodeCallback(BARCODE_BACK_FUNC pBarcodeCB)
{
	m_pFuncBarcodeCB = pBarcodeCB;
}

// Register callback function for device status
void CApp::SetDeviceStatusCallback(DEVICE_STATUS_BACK_FUNC pDeviceStatusCB)
{
	m_pFuncDeviceStatusCB = pDeviceStatusCB;
}

// Register callback function for ink status
void CApp::SetInkStatusCallback(INK_STATUS_BACK_FUNC pInkStatusCB)
{
	m_pFuncInkStatusCB = pInkStatusCB;
}

// Obtain barcode data
int CApp::GetBarcode(CBarcodeResult *pBarcodeResult)
{
	return m_CCBarcode.GetBarcode(pBarcodeResult);
}

// Get device status
int CApp::GetDeviceStatusFunction(CDeviceStatus *pDeviceStatus)
{
	return m_CCInfo.GetDeviceStatusFunction(pDeviceStatus);
}

// Get ink status
int CApp::GetInkStatusFunction(CInkStatus* pInkStatus)
{
	return m_CCInfo.GetInkStatusFunction(pInkStatus);
}

// Get device information
int CApp::GetDeviceInfo(CDeviceInfo* pDeviceInfo)
{
	return m_CCInfo.GetDeviceInfoFunction(pDeviceInfo);
}

// Get maintenace counters
int CApp::GetMaintenanceCounter(CMaintenanceCounter* pMaintenanceCounter)
{
	return m_CCInfo.GetMaintenanceCounterFunction(pMaintenanceCounter);
}

// Callback function for notification of device status
int CApp::cbStatus(DWORD dwStatus)
{
	return g_pApp->Status(dwStatus);
}

int CApp::Status(DWORD dwStatus)
{
	if(m_pFuncDeviceStatusCB != NULL)
	{
		m_pFuncDeviceStatusCB();
	}

	return 0;
}

// Callback function for notification of ink status
int CApp::cbInkStatus(WORD wStatus)
{
	return g_pApp->InkStatus(wStatus);
}

int CApp::InkStatus(WORD wStatus)
{
	if(m_pFuncInkStatusCB != NULL)
	{
		m_pFuncInkStatusCB();
	}

	return 0;
}
