#include "stdafx.h"
#include "Barcode.h"

CBarcode::CBarcode(void)
{
	m_pCProperty = NULL;
}

CBarcode::~CBarcode(void)
{
}

int CBarcode::Init(CProperty_1* pProperty)
{
	int nResult = SUCCESS;

	m_pCProperty = pProperty;

	GetAPIProcAddress();

	return nResult;
}

// Set MF_BARCODE structure
int CBarcode::SetBarcodeSetting(void)
{
	int nResult = SUCCESS;

	// Settings for front side
	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfBarcodeFront(), MF_GET_BARCODE_FRONT_DEFAULT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	m_pCProperty->GetMfBarcodeFront()->iSize	= sizeof(MF_BARCODE);
	m_pCProperty->GetMfBarcodeFront()->iVersion	= MF_BARCODE_VERSION;
	// Specify barcode symbols to be decoded
	m_pCProperty->GetMfBarcodeFront()->stInfo[0].dwSymbolMask = m_pCProperty->GetBarcodeTypeMask();

	// Barcode detection error
	m_pCProperty->GetMfBarcodeFront()->bErrorSelect = m_pCProperty->GetBarcodeDetect();
	if( m_pCProperty->GetBarcodeDetect() == MF_ERROR_SELECT_DETECT )
	{
		m_pCProperty->GetMfBarcodeFront()->bErrorEject	= m_pCProperty->GetBarcodeEject();
		m_pCProperty->GetMfBarcodeFront()->bCancel		= m_pCProperty->GetBarcodeCancel();
	}

	nResult = BiSCNMICRFunctionContinuously(m_pCProperty->GetHandle(), m_pCProperty->GetMfBarcodeFront(), MF_SET_BARCODE_FRONT_PARAM);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Obtain barcode data
int CBarcode::GetBarcode(CBarcodeResult* pBarcodeResult)
{
	int nResult = SUCCESS;

	if(pBarcodeResult == NULL)
	{
		return -1;
	}

	nResult = BiSCNSelectScanFace(m_pCProperty->GetHandle(), MF_SCAN_FACE_FRONT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiGetBarcodeData(m_pCProperty->GetHandle(), m_pCProperty->GetTransactionNumber(), m_pCProperty->GetMfBarcodeFront());
	ASSERT( nResult == SUCCESS || nResult == ERR_BARCODE_NODATA );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	if(m_pCProperty->GetMfBarcodeFront()->lpData != NULL)
	{
		CString strBarcodeCombined;
		BARCODE_DATA * pBarcodeData = reinterpret_cast<BARCODE_DATA*>( m_pCProperty->GetMfBarcodeFront()->lpData );
		int nCount = m_pCProperty->GetMfBarcodeFront()->bDataCount;
		for(int nIndex = 0; nIndex < nCount; nIndex++)
		{
			// MFBarcode.BarcodeData.Data must include null terminator.
			// Chop null terminator by shrinking length.
			CString strBarcode((LPCSTR)pBarcodeData[nIndex].pData, (int)pBarcodeData[nIndex].dwDataSize-1);

			// And also, CODE-128 may include null character. Replace it to show on the screen.
			strBarcode.Replace('\0', ' ');

			if ( strBarcodeCombined.IsEmpty() )
			{
				strBarcodeCombined = strBarcode;
			}
			else
			{
				strBarcodeCombined += _T(" ");
				strBarcodeCombined += strBarcode;
			}
			::GlobalFree(pBarcodeData[nIndex].pData);
			pBarcodeData[nIndex].pData = NULL;
		}
		::GlobalFree(m_pCProperty->GetMfBarcodeFront()->lpData);
		m_pCProperty->GetMfBarcodeFront()->lpData = NULL;
		pBarcodeResult->SetBarcodeData(strBarcodeCombined);
	}
	else
	{
		pBarcodeResult->SetBarcodeData(_T(""));
	}


	return nResult;
}

// Get functions of the API
void CBarcode::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_pCProperty->GetLibrary();

	BiSCNMICRFunctionContinuously	= (DLL_BiSCNMICRFunctionContinuously)	GetProcAddress(hLibrary, "BiSCNMICRFunctionContinuously");
	BiGetBarcodeData 				= (DLL_BiGetBarcodeData)				GetProcAddress(hLibrary, "BiGetBarcodeData");
	BiSCNSelectScanFace				= (DLL_BiSCNSelectScanFace)				GetProcAddress(hLibrary, "BiSCNSelectScanFace");
}

