Imports System.Diagnostics
Imports com.epson.bank.driver

Namespace TMS_Sample
	Class CApp
		Public Const EXEC_SCAN_CHECK As Byte = 0
		Public Const EXEC_SCAN_CARD As Byte = 1

		' Step 1
		Public Delegate Sub CallbackProcProcessError(errResult As ErrorCode)

		' Step 1
		Private m_cbFuncProcessErrorCB As CallbackProcProcessError = Nothing

		Private m_objProperty As CProperty_1 = Nothing
		Private m_bOpenDevice As Boolean
		Private m_objScan As CScan = Nothing
		Private m_objMicr As CMicr = Nothing
		Private m_objOption As COption = Nothing

		Public Sub New()
			' Step 1
			m_objProperty = New CProperty_1()
			m_objScan = New CScan()
			m_objMicr = New CMicr()
			m_objOption = New COption()
		End Sub

		' Initialize
		Public Function InitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			m_bOpenDevice = False

			Try
				' Connect to the device
				m_objProperty.SetMfDevice(New MFDevice())
				errResult = m_objProperty.GetMfDevice().OpenMonPrinter(OpenType.TYPE_PRINTER, "TM-S9000U,TM-S2000U")
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = True

				m_objScan.Init(m_objProperty)
				m_objMicr.Init(m_objProperty)
				m_objOption.Init(m_objProperty)

				' Step 1
				' Register callback functions for notification of the reading status
				AddHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)
				errResult = m_objProperty.GetMfDevice().SCNMICRSetStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
			Catch
				Return ErrorCode.ERR_UNKNOWN
			End Try

			Return errResult
		End Function

		' Post process
		Public Function ExitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			If m_bOpenDevice = True Then
				' Cancel the reading status callback
				errResult = m_objProperty.GetMfDevice().SCNMICRCancelStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				RemoveHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)

				' Disconnect from device
				errResult = m_objProperty.GetMfDevice().CloseMonPrinter()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = False
			End If

			Return errResult
		End Function

		' Step 1
		' Register callback function for notification of error during image acquisition
		Public Sub SetProcessErrorCallback(cbProcessErrorCB As CallbackProcProcessError)
			m_cbFuncProcessErrorCB = cbProcessErrorCB
		End Sub

		' Step 1
		' Check scanning process
		Public Function ScanCheck() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Step 1
			' Set MF_BASE01 structure
			errResult = m_objScan.SetBaseSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set check scanning conditions
			errResult = m_objScan.SetScanSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MICR reading conditions
			errResult = m_objMicr.SetMicrSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MF_PROCESS01 structure
			errResult = m_objOption.SetProcessSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Start check scanning
			errResult = m_objScan.ScanFunction()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			Return errResult
		End Function

		' Error recovery
		Public Function CancelError() As ErrorCode
			Return m_objProperty.GetMfDevice().CancelError()
		End Function

		' Get device status
		Public Sub GetDeviceStatus(ByRef eStatus As ASB)
			eStatus = m_objProperty.GetMfDevice().Status
		End Sub

		' Get ink status
		Public Sub GetInkStatus(ByRef eStatus As InkASB)
			eStatus = m_objProperty.GetMfDevice().InkStatus
		End Sub

		' Cancel scanning
		Public Function CancelScan() As ErrorCode
			Return m_objScan.CancelScan()
		End Function

		' Callback function for notifying scanning status
		Private Sub ScanStatus(nTransactionNumber As Integer, eMainStatus As MainStatus, eSubStatus As ErrorCode, strPortName As String)
			If eSubStatus <> ErrorCode.SUCCESS Then
				m_cbFuncProcessErrorCB(eSubStatus)
			End If
		End Sub
	End Class
End Namespace
