Imports System.Diagnostics
Imports com.epson.bank.driver

Namespace TMS_Sample
	Class CApp
		Public Const EXEC_SCAN_CHECK As Byte = 0
		Public Const EXEC_SCAN_CARD As Byte = 1

		' Step 1
		Public Delegate Sub CallbackProcProcessError(errResult As ErrorCode)
		' Step 2
		Public Delegate Sub CallbackProcImage()

		' Step 1
		Private m_cbFuncProcessErrorCB As CallbackProcProcessError = Nothing

		Private m_objProperty As CProperty_1 = Nothing
		Private m_bOpenDevice As Boolean
		Private m_objScan As CScan = Nothing
		Private m_objMicr As CMicr = Nothing
		Private m_objOption As COption = Nothing

		' Step 2
		Private m_objImage As CImage_1 = Nothing

		' Step 2
		Private m_cbFuncImageCB As CallbackProcImage = Nothing

		Public Sub New()
			' Step 1
			m_objProperty = New CProperty_1()
			m_objScan = New CScan()
			m_objMicr = New CMicr()
			m_objOption = New COption()
			' Step 2
			m_objImage = New CImage_1()
		End Sub

		' Initialize
		Public Function InitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			m_bOpenDevice = False

			Try
				' Connect to the device
				m_objProperty.SetMfDevice(New MFDevice())
				errResult = m_objProperty.GetMfDevice().OpenMonPrinter(OpenType.TYPE_PRINTER, "TM-S9000U,TM-S2000U")
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = True

				m_objScan.Init(m_objProperty)
				m_objMicr.Init(m_objProperty)
				m_objOption.Init(m_objProperty)
				' Step 2
				m_objImage.Init(m_objProperty)

				' Step 1
				' Register callback functions for notification of the reading status
				AddHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)
				errResult = m_objProperty.GetMfDevice().SCNMICRSetStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
			Catch
				Return ErrorCode.ERR_UNKNOWN
			End Try

			Return errResult
		End Function

		' Post process
		Public Function ExitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			If m_bOpenDevice = True Then
				' Cancel the reading status callback
				errResult = m_objProperty.GetMfDevice().SCNMICRCancelStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				RemoveHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)

				' Disconnect from device
				errResult = m_objProperty.GetMfDevice().CloseMonPrinter()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = False
			End If

			Return errResult
		End Function

		' Step 1
		' Register callback function for notification of error during image acquisition
		Public Sub SetProcessErrorCallback(cbProcessErrorCB As CallbackProcProcessError)
			m_cbFuncProcessErrorCB = cbProcessErrorCB
		End Sub

		' Step 2
		' Register callback function for notification of the image data
		Public Sub SetImageCallback(cbImageCB As CallbackProcImage)
			m_cbFuncImageCB = cbImageCB
		End Sub

		' Set scanning parameters
		Public Sub SetScanParam(objScanParam As CScanParam)
			If objScanParam IsNot Nothing Then
				m_objProperty.SetScanMedia(objScanParam.GetScanMedia())
				m_objProperty.SetLightSourceToScan(objScanParam.GetLightSourceToScan())
				m_objProperty.SetRGBColorDepth(objScanParam.GetRGBColorDepth())
				m_objProperty.SetIRColorDepth(objScanParam.GetIRColorDepth())
				m_objProperty.SetResolution(objScanParam.GetResolution())
				m_objProperty.SetNumberOfDocuments(objScanParam.GetNumberOfDocuments())
			End If
		End Sub

		' Get scanning parameters
		Public Sub GetScanParam(ByRef objScanParam As CScanParam)
			If objScanParam IsNot Nothing Then
				objScanParam.SetScanMedia(m_objProperty.GetScanMedia())
				objScanParam.SetLightSourceToScan(m_objProperty.GetLightSourceToScan())
				objScanParam.SetRGBColorDepth(m_objProperty.GetRGBColorDepth())
				objScanParam.SetIRColorDepth(m_objProperty.GetIRColorDepth())
				objScanParam.SetResolution(m_objProperty.GetResolution())
				objScanParam.SetNumberOfDocuments(m_objProperty.GetNumberOfDocuments())
			End If
		End Sub

		' Step 1
		' Check scanning process
		Public Function ScanCheck() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Step 1
			' Set MF_BASE01 structure
			errResult = m_objScan.SetBaseSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set check scanning conditions
			errResult = m_objScan.SetScanSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MICR reading conditions
			errResult = m_objMicr.SetMicrSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MF_PROCESS01 structure
			errResult = m_objOption.SetProcessSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Start check scanning
			errResult = m_objScan.ScanFunction()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			Return errResult
		End Function

		' Step 2
		' Card scanning process
		Public Function ScanCard() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Step 2
			' Clear MF_MICR strucuture
			errResult = m_objMicr.ClearMicrSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MF_BASE01 strucuture
			errResult = m_objScan.SetBaseSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set card scanning conditions
			errResult = m_objScan.SetScanSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Start card scanning
			errResult = m_objScan.ScanFunction()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			Return errResult
		End Function

		' Check if scanning card with IR in 1 pass is supported.
		Public Function IsScanningCardIR1PassSupported() As Boolean
			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			Dim DeviceInfo As Byte() = Nothing

			errResult = m_objProperty.GetMfDevice().GetPrnCapability(112, DeviceInfo)
			If errResult = ErrorCode.SUCCESS AndAlso DeviceInfo.Length >= 1 Then
				If (DeviceInfo(0) And &H20) = &H20 Then
					Return True
				End If
			End If
			Return False
		End Function

		' Get image data
		Public Function GetScanImage(ByRef objImageResult As CImageResult) As ErrorCode
			Return m_objImage.GetScanImage(objImageResult)
		End Function

		' Error recovery
		Public Function CancelError() As ErrorCode
			Return m_objProperty.GetMfDevice().CancelError()
		End Function

		' Get device status
		Public Sub GetDeviceStatus(ByRef eStatus As ASB)
			eStatus = m_objProperty.GetMfDevice().Status
		End Sub

		' Get ink status
		Public Sub GetInkStatus(ByRef eStatus As InkASB)
			eStatus = m_objProperty.GetMfDevice().InkStatus
		End Sub

		' Cancel scanning
		Public Function CancelScan() As ErrorCode
			Return m_objScan.CancelScan()
		End Function

		' Callback function for notifying scanning status
		Private Sub ScanStatus(nTransactionNumber As Integer, eMainStatus As MainStatus, eSubStatus As ErrorCode, strPortName As String)
			If eSubStatus <> ErrorCode.SUCCESS Then
				m_cbFuncProcessErrorCB(eSubStatus)
			End If

			' Step 2
			If eMainStatus = MainStatus.MF_DATARECEIVE_DONE Then
				m_objProperty.SetTransactionNumber(nTransactionNumber)

				' Step 2
				' Notify callback for image data
				m_cbFuncImageCB()
			End If
		End Sub
	End Class
End Namespace
