Imports System.Diagnostics
Imports com.epson.bank.driver

Namespace TMS_Sample
	Class CApp
		Public Const EXEC_SCAN_CHECK As Byte = 0
		Public Const EXEC_SCAN_CARD As Byte = 1

		' Step 1
		Public Delegate Sub CallbackProcProcessError(errResult As ErrorCode)
		' Step 2
		Public Delegate Sub CallbackProcImage()
		' Step 3
		Public Delegate Sub CallbackProcMicr()
		' Step 8
		Public Delegate Sub CallbackProcBarcode()
		Public Delegate Sub CallbackProcDeviceStatus()
		Public Delegate Sub CallbackProcInkStatus()

		' Step 1
		Private m_cbFuncProcessErrorCB As CallbackProcProcessError = Nothing

		Private m_objProperty As CProperty_1 = Nothing
		Private m_bOpenDevice As Boolean
		Private m_objScan As CScan = Nothing
		Private m_objMicr As CMicr = Nothing
		Private m_objOption As COption = Nothing

		' Step 2
		Private m_objImage As CImage_1 = Nothing

		' Step 2
		Private m_cbFuncImageCB As CallbackProcImage = Nothing

		' Step 3
		Private m_byExecType As Byte
		Private m_cbFuncMicrCB As CallbackProcMicr = Nothing

		' Step 8
		Private m_objBarcode As CBarcode
		Private m_objInfo As CInfo
		Private m_cbFuncBarcodeCB As CallbackProcBarcode = Nothing
		Private m_cbFuncDeviceStatusCB As CallbackProcDeviceStatus = Nothing
		Private m_cbFuncInkStatusCB As CallbackProcInkStatus = Nothing

		Public Sub New()
			' Step 1
			m_objProperty = New CProperty_1()
			m_objScan = New CScan()
			m_objMicr = New CMicr()
			m_objOption = New COption()
			' Step 2
			m_objImage = New CImage_1()

			' Step 3
			m_byExecType = EXEC_SCAN_CHECK

			' Step 8
			m_objBarcode = New CBarcode()
			m_objInfo = New CInfo()
		End Sub

		' Initialize
		Public Function InitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			m_bOpenDevice = False

			Try
				' Connect to the device
				m_objProperty.SetMfDevice(New MFDevice())
				errResult = m_objProperty.GetMfDevice().OpenMonPrinter(OpenType.TYPE_PRINTER, "TM-S9000U,TM-S2000U")
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = True

				m_objScan.Init(m_objProperty)
				m_objMicr.Init(m_objProperty)
				m_objOption.Init(m_objProperty)
				' Step 2
				m_objImage.Init(m_objProperty)

				' Step 8
				m_objBarcode.Init(m_objProperty)
				m_objInfo.Init(m_objProperty)

				' Step 1
				' Register callback functions for notification of the reading status
				AddHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)
				errResult = m_objProperty.GetMfDevice().SCNMICRSetStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If

				' Step 8
				' Register callback function for notification of the device status
				AddHandler m_objProperty.GetMfDevice().StatusCallback, New MFDevice.StatusCallbackHandler(AddressOf Status)
				errResult = m_objProperty.GetMfDevice().SetStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If

				' Register callback function for notification of ink status
				AddHandler m_objProperty.GetMfDevice().InkStatusCallback, New MFDevice.InkStatusCallbackHandler(AddressOf InkStatus)
				errResult = m_objProperty.GetMfDevice().SetInkStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
			Catch
				Return ErrorCode.ERR_UNKNOWN
			End Try

			Return errResult
		End Function

		' Post process
		Public Function ExitDevice() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			If m_bOpenDevice = True Then
				' Cancel the reading status callback
				errResult = m_objProperty.GetMfDevice().SCNMICRCancelStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				RemoveHandler m_objProperty.GetMfDevice().SCNMICRStatusCallback, New MFDevice.SCNMICRStatusCallbackHandler(AddressOf ScanStatus)

				' Step 8
				' Register callback function for notification of the device status
				errResult = m_objProperty.GetMfDevice().CancelStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				RemoveHandler m_objProperty.GetMfDevice().StatusCallback, New MFDevice.StatusCallbackHandler(AddressOf Status)

				' Cancel the ink status callback
				errResult = m_objProperty.GetMfDevice().CancelInkStatusBack()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				RemoveHandler m_objProperty.GetMfDevice().InkStatusCallback, New MFDevice.InkStatusCallbackHandler(AddressOf InkStatus)

				' Disconnect from device
				errResult = m_objProperty.GetMfDevice().CloseMonPrinter()
				Debug.Assert(errResult = ErrorCode.SUCCESS)
				If errResult <> ErrorCode.SUCCESS Then
					Return errResult
				End If
				m_bOpenDevice = False
			End If

			Return errResult
		End Function

		' Step 1
		' Register callback function for notification of error during image acquisition
		Public Sub SetProcessErrorCallback(cbProcessErrorCB As CallbackProcProcessError)
			m_cbFuncProcessErrorCB = cbProcessErrorCB
		End Sub

		' Step 2
		' Register callback function for notification of the image data
		Public Sub SetImageCallback(cbImageCB As CallbackProcImage)
			m_cbFuncImageCB = cbImageCB
		End Sub

		' Step 3
		' Register callback function for notification of the MICR data
		Public Sub SetMicrCallback(cbMicrCB As CallbackProcMicr)
			m_cbFuncMicrCB = cbMicrCB
		End Sub

		' Set MICR settings
		Public Sub SetMicrParam(objMicrParam As CMicrParam)
			If objMicrParam IsNot Nothing Then
				m_objProperty.SetFont(objMicrParam.GetFont())
				m_objProperty.SetParsing(objMicrParam.GetParsing())
				m_objProperty.SetClearSpace(objMicrParam.GetClearSpace())
			End If
		End Sub

		' Get MICR settings
		Public Sub GetMicrParam(ByRef objMicrParam As CMicrParam)
			If objMicrParam IsNot Nothing Then
				objMicrParam.SetFont(m_objProperty.GetFont())
				objMicrParam.SetParsing(m_objProperty.GetParsing())
				objMicrParam.SetClearSpace(m_objProperty.GetClearSpace())
			End If
		End Sub

		' Set scanning parameters
		Public Sub SetScanParam(objScanParam As CScanParam)
			If objScanParam IsNot Nothing Then
				m_objProperty.SetScanMedia(objScanParam.GetScanMedia())
				m_objProperty.SetLightSourceToScan(objScanParam.GetLightSourceToScan())
				m_objProperty.SetRGBColorDepth(objScanParam.GetRGBColorDepth())
				m_objProperty.SetIRColorDepth(objScanParam.GetIRColorDepth())
				m_objProperty.SetResolution(objScanParam.GetResolution())
				m_objProperty.SetNumberOfDocuments(objScanParam.GetNumberOfDocuments())
			End If
		End Sub

		' Get scanning parameters
		Public Sub GetScanParam(ByRef objScanParam As CScanParam)
			If objScanParam IsNot Nothing Then
				objScanParam.SetScanMedia(m_objProperty.GetScanMedia())
				objScanParam.SetLightSourceToScan(m_objProperty.GetLightSourceToScan())
				objScanParam.SetRGBColorDepth(m_objProperty.GetRGBColorDepth())
				objScanParam.SetIRColorDepth(m_objProperty.GetIRColorDepth())
				objScanParam.SetResolution(m_objProperty.GetResolution())
				objScanParam.SetNumberOfDocuments(m_objProperty.GetNumberOfDocuments())
			End If
		End Sub

		' Step 1
		' Check scanning process
		Public Function ScanCheck() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Step 3
			m_byExecType = EXEC_SCAN_CHECK

			' Step 1
			' Set MF_BASE01 structure
			errResult = m_objScan.SetBaseSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set check scanning conditions
			errResult = m_objScan.SetScanSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MICR reading conditions
			errResult = m_objMicr.SetMicrSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MF_PROCESS01 structure
			errResult = m_objOption.SetProcessSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Step 8
			' Set barcode recoginition conditions
			errResult = m_objBarcode.SetBarcodeSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Start check scanning
			errResult = m_objScan.ScanFunction()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			Return errResult
		End Function

		' Step 2
		' Card scanning process
		Public Function ScanCard() As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Step 3
			m_byExecType = EXEC_SCAN_CARD

			' Step 2
			' Clear MF_MICR strucuture
			errResult = m_objMicr.ClearMicrSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set MF_BASE01 strucuture
			errResult = m_objScan.SetBaseSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Set card scanning conditions
			errResult = m_objScan.SetScanSetting()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			' Start card scanning
			errResult = m_objScan.ScanFunction()
			If errResult <> ErrorCode.SUCCESS Then
				Return errResult
			End If

			Return errResult
		End Function

		' Check if scanning card with IR in 1 pass is supported.
		Public Function IsScanningCardIR1PassSupported() As Boolean
			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			Dim DeviceInfo As Byte() = Nothing

			errResult = m_objProperty.GetMfDevice().GetPrnCapability(112, DeviceInfo)
			If errResult = ErrorCode.SUCCESS AndAlso DeviceInfo.Length >= 1 Then
				If (DeviceInfo(0) And &H20) = &H20 Then
					Return True
				End If
			End If
			Return False
		End Function

		' Get MICR data
		Public Function GetMicr(ByRef objMicrResult As CMicrResult) As ErrorCode
			Return m_objMicr.GetMicr(objMicrResult)
		End Function

		' Get image data
		Public Function GetScanImage(ByRef objImageResult As CImageResult) As ErrorCode
			Return m_objImage.GetScanImage(objImageResult)
		End Function

		' Error recovery
		Public Function CancelError() As ErrorCode
			Return m_objProperty.GetMfDevice().CancelError()
		End Function

		' Get device status
		Public Sub GetDeviceStatus(ByRef eStatus As ASB)
			eStatus = m_objProperty.GetMfDevice().Status
		End Sub

		' Get ink status
		Public Sub GetInkStatus(ByRef eStatus As InkASB)
			eStatus = m_objProperty.GetMfDevice().InkStatus
		End Sub

		' Cancel scanning
		Public Function CancelScan() As ErrorCode
			Return m_objScan.CancelScan()
		End Function

		' Step 3
		' MICR head cleaning
		Public Function CleaningMicr() As ErrorCode
			Return m_objMicr.CleaningMicr()
		End Function

		' Callback function for notifying scanning status
		Private Sub ScanStatus(nTransactionNumber As Integer, eMainStatus As MainStatus, eSubStatus As ErrorCode, strPortName As String)
			If eSubStatus <> ErrorCode.SUCCESS Then
				m_cbFuncProcessErrorCB(eSubStatus)
			End If

			' Step 2
			If eMainStatus = MainStatus.MF_DATARECEIVE_DONE Then
				m_objProperty.SetTransactionNumber(nTransactionNumber)

				' Step 2
				' Notify callback for image data
				m_cbFuncImageCB()

				' Step 3
				If m_byExecType = EXEC_SCAN_CHECK Then
					' Step 3
					' Notify callback for MICR data
					m_cbFuncMicrCB()

					' Step 8
					' Notify callback for barcode data
					m_cbFuncBarcodeCB()
				End If
			End If
		End Sub

		'''/////////////
		'''/ Step 8 ////
		'''/////////////

		' Set processing mode options
		Public Sub SetOptionParam(objOptionParam As COptionParam)
			If objOptionParam IsNot Nothing Then
				m_objProperty.SetPaperMisInsertionDetect(objOptionParam.GetPaperMisInsertionDetect())
				m_objProperty.SetPaperMisInsertionCancel(objOptionParam.GetPaperMisInsertionCancel())
				m_objProperty.SetPaperMisInsertionEject(objOptionParam.GetPaperMisInsertionEject())
				m_objProperty.SetNoiseDetect(objOptionParam.GetNoiseDetect())
				m_objProperty.SetNoiseCancel(objOptionParam.GetNoiseCancel())
				m_objProperty.SetNoiseEject(objOptionParam.GetNoiseEject())
				m_objProperty.SetDoubleFeedDetect(objOptionParam.GetDoubleFeedDetect())
				m_objProperty.SetDoubleFeedCancel(objOptionParam.GetDoubleFeedCancel())
				m_objProperty.SetDoubleFeedEject(objOptionParam.GetDoubleFeedEject())
				m_objProperty.SetBaddataDetect(objOptionParam.GetBaddataDetect())
				m_objProperty.SetBaddataCancel(objOptionParam.GetBaddataCancel())
				m_objProperty.SetBaddataEject(objOptionParam.GetBaddataEject())
				m_objProperty.SetNodataDetect(objOptionParam.GetNodataDetect())
				m_objProperty.SetNodataCancel(objOptionParam.GetNodataCancel())
				m_objProperty.SetNodataEject(objOptionParam.GetNodataEject())
			End If
		End Sub

		' Get processing mode options
		Public Sub GetOptionParam(ByRef objOptionParam As COptionParam)
			If objOptionParam IsNot Nothing Then
				objOptionParam.SetPaperMisInsertionDetect(m_objProperty.GetPaperMisInsertionDetect())
				objOptionParam.SetPaperMisInsertionCancel(m_objProperty.GetPaperMisInsertionCancel())
				objOptionParam.SetPaperMisInsertionEject(m_objProperty.GetPaperMisInsertionEject())
				objOptionParam.SetNoiseDetect(m_objProperty.GetNoiseDetect())
				objOptionParam.SetNoiseCancel(m_objProperty.GetNoiseCancel())
				objOptionParam.SetNoiseEject(m_objProperty.GetNoiseEject())
				objOptionParam.SetDoubleFeedDetect(m_objProperty.GetDoubleFeedDetect())
				objOptionParam.SetDoubleFeedCancel(m_objProperty.GetDoubleFeedCancel())
				objOptionParam.SetDoubleFeedEject(m_objProperty.GetDoubleFeedEject())
				objOptionParam.SetBaddataDetect(m_objProperty.GetBaddataDetect())
				objOptionParam.SetBaddataCancel(m_objProperty.GetBaddataCancel())
				objOptionParam.SetBaddataEject(m_objProperty.GetBaddataEject())
				objOptionParam.SetNodataDetect(m_objProperty.GetNodataDetect())
				objOptionParam.SetNodataCancel(m_objProperty.GetNodataCancel())
				objOptionParam.SetNodataEject(m_objProperty.GetNodataEject())
			End If
		End Sub

		'''/////////////
		'''/ Step 8 ////
		'''/////////////

		' Set barcode recognition settings
		Public Sub SetBarcodeParam(objBarcodeParam As CBarcodeParam)
			If objBarcodeParam IsNot Nothing Then
				m_objProperty.SetBarcodeTypeMask(objBarcodeParam.GetBarcodeTypeMask())
				m_objProperty.SetBarcodeDetect(objBarcodeParam.GetBarcodeDetect())
				m_objProperty.SetBarcodeCancel(objBarcodeParam.GetBarcodeCancel())
				m_objProperty.SetBarcodeEject(objBarcodeParam.GetBarcodeEject())
			End If
		End Sub

		' Get barcode recognition settings
		Public Sub GetBarcodeParam(ByRef objBarcodeParam As CBarcodeParam)
			If objBarcodeParam IsNot Nothing Then
				objBarcodeParam.SetBarcodeTypeMask(m_objProperty.GetBarcodeTypeMask())
				objBarcodeParam.SetBarcodeDetect(m_objProperty.GetBarcodeDetect())
				objBarcodeParam.SetBarcodeCancel(m_objProperty.GetBarcodeCancel())
				objBarcodeParam.SetBarcodeEject(m_objProperty.GetBarcodeEject())
			End If
		End Sub

		' Regsiter callback function for barcode recognition
		Public Sub SetBarcodeCallback(cbBarcodeCB As CallbackProcBarcode)
			m_cbFuncBarcodeCB = cbBarcodeCB
		End Sub

		' Register callback function for device status
		Public Sub SetDeviceStatusCallback(cbDeviceStatusCB As CallbackProcDeviceStatus)
			m_cbFuncDeviceStatusCB = cbDeviceStatusCB
		End Sub

		' Register callback function for ink status
		Public Sub SetInkStatusCallback(cbInkStatusCB As CallbackProcInkStatus)
			m_cbFuncInkStatusCB = cbInkStatusCB
		End Sub

		' Obtain barcode data
		Public Function GetBarcode(ByRef objBarcodeResult As CBarcodeResult) As ErrorCode
			Return m_objBarcode.GetBarcode(objBarcodeResult)
		End Function

		' Get device status
		Public Function GetDeviceStatusFunction(ByRef objDeviceStatus As CDeviceStatus) As ErrorCode
			Return m_objInfo.GetDeviceStatusFunction(objDeviceStatus)
		End Function

		' Get ink status
		Public Function GetInkStatusFunction(ByRef objInkStatus As CInkStatus) As ErrorCode
			Return m_objInfo.GetInkStatusFunction(objInkStatus)
		End Function

		' Get device information
		Public Function GetDeviceInfo(ByRef objDeviceInfo As CDeviceInfo) As ErrorCode
			Return m_objInfo.GetDeviceInfoFunction(objDeviceInfo)
		End Function

		' Get maintenace counters
		Public Function GetMaintenanceCounter(ByRef objMaintenanceCounter As CMaintenanceCounter) As ErrorCode
			Return m_objInfo.GetMaintenanceCounterFunction(objMaintenanceCounter)
		End Function

		' Callback function for notification of device status
		Public Sub Status(eStatus As ASB)
			m_cbFuncDeviceStatusCB()
		End Sub

		' Callback function for notification of ink status
		Public Sub InkStatus(eInkStatus As InkASB)
			m_cbFuncInkStatusCB()
		End Sub
	End Class
End Namespace
